/***************************
 * Pocillo!_GTK+ Version 3.0.2 *
 ***************************/
/*
$tiny_size: if($compact == 'false', 8px, 4px);
$smaller_size: if($compact == 'false', 12px, 8px);
$small_size: if($compact == 'false', 24px, 20px);
$medium_size: if($compact == 'false', 36px, 32px);
$large_size: if($compact == 'false', 48px, 40px);
*/
/*

    <rect fill="#5294e2" x="0" y="0" width="64" height="360"/>
    <rect fill="#4dadd4" x="64" y="0" width="64" height="360"/>
    <rect fill="#73d216" x="128" y="0" width="64" height="360"/>
    <rect fill="#fc4138" x="192" y="0" width="64" height="360"/>
    <rect fill="#f04a50" x="256" y="0" width="64" height="360"/>
    <rect fill="#383c4a" x="320" y="0" width="64" height="360"/>
    <rect fill="#404552" x="384" y="0" width="64" height="360"/>
    <rect fill="#5c616c" x="448" y="0" width="64" height="360"/>
    <rect fill="#d3dae3" x="512" y="0" width="64" height="360"/>
    <rect fill="#f5f6f7" x="576" y="0" width="64" height="360"/>
*/
@keyframes ripple_effect {
  to {
    background-size: 1000% 1000%;
  }
}

@keyframes header_ripple_effect {
  from {
    background-image: radial-gradient(circle farthest-corner at center, #4D90D6 0%, transparent 0%);
  }
  to {
    background-image: radial-gradient(circle farthest-corner at center, #4D90D6 100%, transparent 0%);
  }
}

* {
  background-clip: padding-box;
  -GtkToolButton-icon-spacing: 0;
  -GtkTextView-error-underline-color: #c10c03;
  -GtkScrolledWindow-scrollbar-spacing: 0;
  -GtkToolItemGroup-expander-size: 11;
  -GtkWidget-text-handle-width: 24;
  -GtkWidget-text-handle-height: 24;
  -GtkDialog-button-spacing: 4;
  -GtkDialog-action-area-border: 0;
  outline-style: solid;
  outline-width: 2px;
  outline-color: transparent;
  outline-offset: -4px;
  -gtk-outline-radius: 2px;
  -gtk-secondary-caret-color: #4D90D6;
}

switch:focus slider,
notebook:focus tab,
*:focus {
  outline-color: alpha(currentColor, 0.3);
}

/***************
 * Base States *
 ***************/
.background {
  background-color: white;
  color: rgba(21, 22, 28, 0.85);
}

/*
   These wildcard seems unavoidable, need to investigate.
   Wildcards are bad and troublesome, use them with care,
   or better, just don't.
   Everytime a wildcard is used a kitten dies, painfully.
*/
*:disabled {
  -gtk-icon-effect: dim;
}

.gtkstyle-fallback {
  background-color: white;
  color: rgba(21, 22, 28, 0.85);
}

.gtkstyle-fallback:hover {
  background-color: #f2f2f2;
  color: rgba(21, 22, 28, 0.85);
}

.gtkstyle-fallback:active {
  background-color: #e6e6e6;
  color: rgba(21, 22, 28, 0.85);
}

.gtkstyle-fallback:disabled {
  background-color: white;
  color: rgba(21, 22, 28, 0.38);
}

.gtkstyle-fallback:selected {
  background-color: #4D90D6;
  color: #FFFFFF;
}

.view {
  background-color: #FFFFFF;
  color: rgba(21, 22, 28, 0.85);
}

.view:disabled {
  color: rgba(21, 22, 28, 0.38);
}

.view:hover, .view:active, .view:selected {
  border-radius: 4px;
}

textview text {
  background-color: #FFFFFF;
}

textview border {
  background-color: white;
  color: rgba(21, 22, 28, 0.38);
}

.rubberband,
rubberband,
flowbox rubberband,
.content-view rubberband,
.content-view .rubberband,
treeview.view rubberband {
  border: 1px solid #4D90D6;
  background-color: rgba(77, 144, 214, 0.3);
}

flowbox flowboxchild {
  padding: 4px;
  border-radius: 2px;
}

.content-view .tile:selected {
  background-color: transparent;
  color: inherit;
}

label {
  caret-color: currentColor;
}

label.separator {
  color: rgba(21, 22, 28, 0.85);
}

label selection {
  background-color: #4D90D6;
  color: #FFFFFF;
}

label:disabled {
  color: rgba(21, 22, 28, 0.38);
}

tab label:disabled,
button label:disabled {
  color: inherit;
}

.dim-label, label.separator, .titlebar:not(headerbar) .subtitle,
headerbar .subtitle, .budgie-notification .notification-body, .budgie-switcher .notification-body {
  opacity: 0.6;
}

assistant .sidebar {
  padding: 4px 0;
}

assistant .sidebar label {
  min-height: 32px;
  padding: 0 12px;
  color: rgba(21, 22, 28, 0.85);
  font-weight: 500;
}

assistant .sidebar label.highlight {
  color: rgba(21, 22, 28, 0.85);
}

.osd .scale-popup, .app-notification, popover.background.touch-selection, popover.background.magnifier, popover.background.osd, .nautilus-window .floating-bar, .osd {
  opacity: 0.9;
}

/***********
 * Buttons *
 ***********/
widget > box.workspace-switcher button.image-button.workspace-add-button,
button {
  min-height: 24px;
  min-width: 24px;
  padding: 6px 8px;
  border-radius: 4px;
  font-weight: 500;
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1), box-shadow 180ms cubic-bezier(0.4, 0, 0.2, 1);
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24), inset 0 0 0 9999px transparent;
  background-color: white;
  color: rgba(21, 22, 28, 0.75);
}

widget > box.workspace-switcher button.image-button.workspace-add-button:backdrop,
button:backdrop {
  color: rgba(135, 135, 135, 0.825);
}

widget > box.workspace-switcher button.image-button.workspace-add-button:hover,
button:hover {
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23), inset 0 0 0 9999px transparent;
  color: rgba(21, 22, 28, 0.85);
}

widget > box.workspace-switcher button.image-button.workspace-add-button:active,
button:active {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1);
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23), inset 0 0 0 9999px alpha(currentColor, 0.15);
  color: rgba(21, 22, 28, 0.85);
}

widget > box.workspace-switcher button.image-button.workspace-add-button:disabled,
button:disabled {
  box-shadow: none;
  background-color: rgba(56, 60, 74, 0.12);
  color: rgba(21, 22, 28, 0.26);
}

widget > box.workspace-switcher button.image-button.workspace-add-button:checked,
button:checked {
  background-color: #4D90D6;
  color: #FFFFFF;
  /*
      &:backdrop { 
        background-color: lighten(desaturate($accent_color, 35%), 15%);
        color: 
      }*/
}

widget > box.workspace-switcher button.image-button.workspace-add-button:checked:backdrop,
button:checked:backdrop {
  background-color: #a8c4e0;
  color: white;
}

widget > box.workspace-switcher button.image-button.workspace-add-button:checked:disabled,
button:checked:disabled {
  background-color: rgba(77, 144, 214, 0.3);
  color: rgba(77, 144, 214, 0.5);
}

widget > box.workspace-switcher button.image-button.workspace-add-button:checked:disabled:backdrop,
button:checked:disabled:backdrop {
  opacity: 0.5;
}

modelbutton.flat,
.menuitem.button.flat, check,
radio, spinbutton:not(.vertical) button, spinbutton.vertical button, calendar.button, notebook > header > tabs > arrow, popover.background.menu button,
popover.background button.model, scrollbar button, button.sidebar-button, messagedialog.csd .dialog-action-area button, PanelToplevel > grid > button, .raven .raven-header:not(.top) button, .drop-shadow button, .budgie-session-dialog .linked.horizontal > button, .gedit-search-slider button, .lightdm-gtk-greeter button, :not(headerbar) .caja-pathbar button, .caja-pathbar :not(headerbar) button, :not(headerbar)
.path-bar button, .mate-panel-menu-bar #PanelApplet button, .budgie-panel #tasklist-button, .raven stackswitcher.linked > button, actionbar > revealer > box button:not(.suggested-action):not(.destructive-action):not(.server-list-button), .titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action),
headerbar button:not(.suggested-action):not(.destructive-action), .app-notification button, toolbar button, widget > box.workspace-switcher button.flat.image-button.workspace-add-button,
button.flat {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1);
  box-shadow: inset 0 0 0 9999px transparent;
  background-color: transparent;
  color: rgba(21, 22, 28, 0.54);
}

modelbutton.flat:hover,
.menuitem.button.flat:hover, check:hover,
radio:hover, spinbutton:not(.vertical) button:hover, spinbutton.vertical button:hover, calendar.button:hover, notebook > header > tabs > arrow:hover, popover.background.menu button:hover,
popover.background button.model:hover, scrollbar button:hover, button.sidebar-button:hover, messagedialog.csd .dialog-action-area button:hover, PanelToplevel > grid > button:hover, .raven .raven-header:not(.top) button:hover, .drop-shadow button:hover, .budgie-session-dialog .linked.horizontal > button:hover, .gedit-search-slider button:hover, .lightdm-gtk-greeter button:hover, :not(headerbar) .caja-pathbar button:hover, .caja-pathbar :not(headerbar) button:hover, :not(headerbar)
.path-bar button:hover, .mate-panel-menu-bar #PanelApplet button:hover, .budgie-panel #tasklist-button:hover, .raven stackswitcher.linked > button:hover, actionbar > revealer > box button:hover:not(.suggested-action):not(.destructive-action):not(.server-list-button), .titlebar:not(headerbar) button:hover:not(.suggested-action):not(.destructive-action),
headerbar button:hover:not(.suggested-action):not(.destructive-action), .app-notification button:hover, toolbar button:hover, widget > box.workspace-switcher button.flat.image-button.workspace-add-button:hover,
button.flat:hover {
  box-shadow: inset 0 0 0 9999px alpha(currentColor, 0.15);
  color: rgba(21, 22, 28, 0.85);
}

modelbutton.flat:active,
.menuitem.button.flat:active, check:active,
radio:active, spinbutton:not(.vertical) button:active, spinbutton.vertical button:active, calendar.button:active, notebook > header > tabs > arrow:active, popover.background.menu button:active,
popover.background button.model:active, scrollbar button:active, button.sidebar-button:active, messagedialog.csd .dialog-action-area button:active, PanelToplevel > grid > button:active, .raven .raven-header:not(.top) button:active, .drop-shadow button:active, .budgie-session-dialog .linked.horizontal > button:active, .gedit-search-slider button:active, .lightdm-gtk-greeter button:active, :not(headerbar) .caja-pathbar button:active, .caja-pathbar :not(headerbar) button:active, :not(headerbar)
.path-bar button:active, .mate-panel-menu-bar #PanelApplet button:active, .budgie-panel #tasklist-button:active, .raven stackswitcher.linked > button:active, actionbar > revealer > box button:active:not(.suggested-action):not(.destructive-action):not(.server-list-button), .titlebar:not(headerbar) button:active:not(.suggested-action):not(.destructive-action),
headerbar button:active:not(.suggested-action):not(.destructive-action), .app-notification button:active, toolbar button:active, widget > box.workspace-switcher button.flat.image-button.workspace-add-button:active,
button.flat:active {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1);
  box-shadow: inset 0 0 0 9999px alpha(currentColor, 0.15);
  color: rgba(21, 22, 28, 0.85);
}

modelbutton.flat:disabled,
.menuitem.button.flat:disabled, check:disabled,
radio:disabled, spinbutton:not(.vertical) button:disabled, spinbutton.vertical button:disabled, calendar.button:disabled, notebook > header > tabs > arrow:disabled, popover.background.menu button:disabled,
popover.background button.model:disabled, scrollbar button:disabled, button.sidebar-button:disabled, messagedialog.csd .dialog-action-area button:disabled, PanelToplevel > grid > button:disabled, .raven .raven-header:not(.top) button:disabled, .drop-shadow button:disabled, .budgie-session-dialog .linked.horizontal > button:disabled, .gedit-search-slider button:disabled, .lightdm-gtk-greeter button:disabled, :not(headerbar) .caja-pathbar button:disabled, .caja-pathbar :not(headerbar) button:disabled, :not(headerbar)
.path-bar button:disabled, .mate-panel-menu-bar #PanelApplet button:disabled, .budgie-panel #tasklist-button:disabled, .raven stackswitcher.linked > button:disabled, actionbar > revealer > box button:disabled:not(.suggested-action):not(.destructive-action):not(.server-list-button), .titlebar:not(headerbar) button:disabled:not(.suggested-action):not(.destructive-action),
headerbar button:disabled:not(.suggested-action):not(.destructive-action), .app-notification button:disabled, toolbar button:disabled, widget > box.workspace-switcher button.flat.image-button.workspace-add-button:disabled,
button.flat:disabled {
  box-shadow: none;
  background-color: transparent;
  color: rgba(21, 22, 28, 0.26);
}

:not(headerbar) .caja-pathbar button:checked, .caja-pathbar :not(headerbar) button:checked, :not(headerbar)
.path-bar button:checked, .mate-panel-menu-bar #PanelApplet button:checked, .budgie-panel #tasklist-button:checked, .raven stackswitcher.linked > button:checked, actionbar > revealer > box button:checked:not(.suggested-action):not(.destructive-action):not(.server-list-button), .titlebar:not(headerbar) button:checked:not(.suggested-action):not(.destructive-action),
headerbar button:checked:not(.suggested-action):not(.destructive-action), .app-notification button:checked, toolbar button:checked, widget > box.workspace-switcher button.flat.image-button.workspace-add-button:checked,
button.flat:checked {
  background-color: rgba(0, 0, 0, 0.26);
  color: rgba(21, 22, 28, 0.85);
}

:not(headerbar) .caja-pathbar button:checked:disabled, .caja-pathbar :not(headerbar) button:checked:disabled, :not(headerbar)
.path-bar button:checked:disabled, .mate-panel-menu-bar #PanelApplet button:checked:disabled, .budgie-panel #tasklist-button:checked:disabled, .raven stackswitcher.linked > button:checked:disabled, actionbar > revealer > box button:checked:disabled:not(.suggested-action):not(.destructive-action):not(.server-list-button), .titlebar:not(headerbar) button:checked:disabled:not(.suggested-action):not(.destructive-action),
headerbar button:checked:disabled:not(.suggested-action):not(.destructive-action), .app-notification button:checked:disabled, toolbar button:checked:disabled, widget > box.workspace-switcher button.flat.image-button.workspace-add-button:checked:disabled,
button.flat:checked:disabled {
  background-color: rgba(56, 60, 74, 0.12);
  color: rgba(21, 22, 28, 0.38);
}

widget > box.workspace-switcher button.text-button.image-button.workspace-add-button,
button.text-button {
  padding-left: 12px;
  padding-right: 12px;
}

widget > box.workspace-switcher button.image-button.workspace-add-button,
button.image-button {
  min-width: 24px;
  min-height: 24px;
  padding: 6px;
}

widget > box.workspace-switcher button.text-button.image-button.workspace-add-button,
button.text-button.image-button {
  border-radius: 4px;
  -gtk-outline-radius: 4px;
}

widget > box.workspace-switcher button.text-button.image-button.workspace-add-button label:first-child,
button.text-button.image-button label:first-child {
  margin-left: 6px;
}

widget > box.workspace-switcher button.text-button.image-button.workspace-add-button label:last-child,
button.text-button.image-button label:last-child {
  margin-right: 6px;
}

widget > box.workspace-switcher button.text-button.image-button.workspace-add-button image:not(:only-child),
button.text-button.image-button image:not(:only-child) {
  margin: 0 6px;
}

actionbar > revealer > box .linked > button:not(.suggested-action):not(.destructive-action):not(.server-list-button), .titlebar:not(headerbar) .linked > button:not(.suggested-action):not(.destructive-action),
headerbar .linked > button:not(.suggested-action):not(.destructive-action), .app-notification .linked > button, toolbar .linked > button, widget > box.workspace-switcher .linked > button.flat.image-button.workspace-add-button, actionbar > revealer > box
.linked.vertical > button:not(.suggested-action):not(.destructive-action):not(.server-list-button), .titlebar:not(headerbar)
.linked.vertical > button:not(.suggested-action):not(.destructive-action),
headerbar
.linked.vertical > button:not(.suggested-action):not(.destructive-action), .app-notification
.linked.vertical > button, toolbar
.linked.vertical > button, widget > box.workspace-switcher
.linked.vertical > button.flat.image-button.workspace-add-button, .linked >
button.flat,
.linked.vertical >
button.flat {
  border-radius: 4px;
}

actionbar > revealer > box .linked > button.text-button.image-button:not(.suggested-action):not(.destructive-action):not(.server-list-button), .titlebar:not(headerbar) .linked > button.text-button.image-button:not(.suggested-action):not(.destructive-action),
headerbar .linked > button.text-button.image-button:not(.suggested-action):not(.destructive-action), .app-notification .linked > button.text-button.image-button, toolbar .linked > button.text-button.image-button, widget > box.workspace-switcher .linked > button.flat.text-button.image-button.workspace-add-button, actionbar > revealer > box
.linked.vertical > button.text-button.image-button:not(.suggested-action):not(.destructive-action):not(.server-list-button), .titlebar:not(headerbar)
.linked.vertical > button.text-button.image-button:not(.suggested-action):not(.destructive-action),
headerbar
.linked.vertical > button.text-button.image-button:not(.suggested-action):not(.destructive-action), .app-notification
.linked.vertical > button.text-button.image-button, toolbar
.linked.vertical > button.text-button.image-button, widget > box.workspace-switcher
.linked.vertical > button.flat.text-button.image-button.workspace-add-button, .linked >
button.flat.text-button.image-button,
.linked.vertical >
button.flat.text-button.image-button {
  border-radius: 4px;
  -gtk-outline-radius: 4px;
}

widget > box.workspace-switcher button.image-button.workspace-add-button:drop(active),
button:drop(active) {
  box-shadow: inset 0 0 0 2px #4D90D6;
}

infobar.info button:disabled, infobar.question button:disabled, infobar.warning button:disabled, infobar.error button:disabled, row:selected
button:disabled {
  background-color: rgba(255, 255, 255, 0.12);
  color: rgba(255, 255, 255, 0.3);
}

infobar.info button.flat, infobar.question button.flat, infobar.warning button.flat, infobar.error button.flat, row:selected button.sidebar-button, .budgie-panel button, .budgie-panel #tasklist-button, .raven stackswitcher.linked > button, .raven-mpris button.image-button, .budgie-notification-window button, .budgie-osd-window button, .budgie-switcher-window button, row:selected
button.flat {
  color: rgba(255, 255, 255, 0.7);
}

infobar.info button.flat:hover, infobar.question button.flat:hover, infobar.warning button.flat:hover, infobar.error button.flat:hover, row:selected button.sidebar-button:hover, .budgie-panel button:hover, .budgie-panel #tasklist-button:hover, .raven stackswitcher.linked > button:hover, .raven-mpris button.image-button:hover, .budgie-notification-window button:hover, .budgie-osd-window button:hover, .budgie-switcher-window button:hover, infobar.info button.flat:active, infobar.question button.flat:active, infobar.warning button.flat:active, infobar.error button.flat:active, row:selected button.sidebar-button:active, .budgie-panel button:active, .budgie-panel #tasklist-button:active, .raven stackswitcher.linked > button:active, .raven-mpris button.image-button:active, .budgie-notification-window button:active, .budgie-osd-window button:active, .budgie-switcher-window button:active, row:selected
button.flat:hover, row:selected
button.flat:active {
  color: #FFFFFF;
}

infobar.info button.flat:disabled, infobar.question button.flat:disabled, infobar.warning button.flat:disabled, infobar.error button.flat:disabled, row:selected button.sidebar-button:disabled, .budgie-panel button:disabled, .budgie-panel #tasklist-button:disabled, .raven stackswitcher.linked > button:disabled, .raven-mpris button.image-button:disabled, .budgie-notification-window button:disabled, .budgie-osd-window button:disabled, .budgie-switcher-window button:disabled, row:selected
button.flat:disabled {
  color: rgba(255, 255, 255, 0.3);
}

infobar.info button.flat:checked, infobar.question button.flat:checked, infobar.warning button.flat:checked, infobar.error button.flat:checked, row:selected button.sidebar-button:checked, .budgie-panel button:checked, .budgie-panel #tasklist-button:checked, .raven stackswitcher.linked > button:checked, .raven-mpris button.image-button:checked, .budgie-notification-window button:checked, .budgie-osd-window button:checked, .budgie-switcher-window button:checked, row:selected
button.flat:checked {
  background-color: rgba(255, 255, 255, 0.3);
  color: #FFFFFF;
}

infobar.info button.flat:checked:disabled, infobar.question button.flat:checked:disabled, infobar.warning button.flat:checked:disabled, infobar.error button.flat:checked:disabled, row:selected button.sidebar-button:checked:disabled, .budgie-panel button:checked:disabled, .budgie-panel #tasklist-button:checked:disabled, .raven stackswitcher.linked > button:checked:disabled, .raven-mpris button.image-button:checked:disabled, .budgie-notification-window button:checked:disabled, .budgie-osd-window button:checked:disabled, .budgie-switcher-window button:checked:disabled, row:selected
button.flat:checked:disabled {
  background-color: rgba(255, 255, 255, 0.12);
  color: rgba(255, 255, 255, 0.5);
}


button.osd {
  padding: 12px 16px;
}


button.osd.image-button {
  padding: 12px;
}


button.osd:disabled {
  opacity: 0;
}


button.suggested-action {
  background-color: #437a0d;
  color: #FFFFFF;
}


button.suggested-action:disabled {
  box-shadow: none;
  background-color: rgba(56, 60, 74, 0.12);
  color: rgba(21, 22, 28, 0.38);
}


button.suggested-action:checked {
  background-color: #7ba255;
}


button.suggested-action.flat {
  background-color: transparent;
  color: #437a0d;
}


button.suggested-action.flat:disabled {
  box-shadow: none;
  background-color: transparent;
  color: rgba(21, 22, 28, 0.38);
}


button.suggested-action.flat:checked {
  background-color: rgba(67, 122, 13, 0.3);
}


button.destructive-action {
  background-color: #f80f04;
  color: #FFFFFF;
}


button.destructive-action:disabled {
  box-shadow: none;
  background-color: rgba(56, 60, 74, 0.12);
  color: rgba(21, 22, 28, 0.38);
}


button.destructive-action:checked {
  background-color: #fa574f;
}


button.destructive-action.flat {
  background-color: transparent;
  color: #f80f04;
}


button.destructive-action.flat:disabled {
  box-shadow: none;
  background-color: transparent;
  color: rgba(21, 22, 28, 0.38);
}


button.destructive-action.flat:checked {
  background-color: rgba(248, 15, 4, 0.3);
}

.stack-switcher >
button {
  outline-offset: -4px;
}

.stack-switcher >
button > label {
  padding-left: 6px;
  padding-right: 6px;
}

.stack-switcher >
button > image {
  padding-left: 6px;
  padding-right: 6px;
  padding-top: 3px;
  padding-bottom: 3px;
}

.stack-switcher >
button.text-button {
  padding-left: 12px;
  padding-right: 12px;
}

.stack-switcher >
button.image-button {
  padding-left: 4px;
  padding-right: 4px;
}

.stack-switcher >
button.needs-attention:checked > label,
.stack-switcher >
button.needs-attention:checked > image {
  animation: none;
  background-image: none;
}

.primary-toolbar
button {
  -gtk-icon-shadow: none;
}

widget > box.workspace-switcher button.image-button.workspace-add-button,
button.image-button, actionbar > revealer > box .linked > button.image-button:not(.suggested-action):not(.destructive-action):not(.server-list-button), .titlebar:not(headerbar) .linked > button.image-button:not(.suggested-action):not(.destructive-action),
headerbar .linked > button.image-button:not(.suggested-action):not(.destructive-action), .app-notification .linked > button.image-button, toolbar .linked > button.image-button, widget > box.workspace-switcher .linked > button.flat.image-button.workspace-add-button,
headerbar
.linked.vertical > button.image-button:not(.suggested-action):not(.destructive-action), .app-notification
.linked.vertical > button.image-button, toolbar
.linked.vertical > button.image-button, .linked > button.flat.image-button,
.linked.vertical > button.flat.image-button, .inline-toolbar button:not(.text-button), button.titlebutton, .raven .raven-header:not(.top) button.image-button, .raven .expander-button, .nautilus-window headerbar > revealer > button,
button.close,
button.circular {
  border-radius: 9999px;
  -gtk-outline-radius: 9999px;
}

spinbutton:not(.vertical) button, notebook > header tab button.flat, button.sidebar-button, .pluma-window paned.horizontal box.vertical box.horizontal button.flat, .nautilus-window .floating-bar button, .gedit-document-panel row button.flat, .gedit-search-slider button:dir(ltr), .gedit-search-slider button:dir(rtl) {
  min-height: 20px;
  min-width: 20px;
  padding: 0;
  border-radius: 9999px;
  -gtk-outline-radius: 9999px;
}

.stack-switcher >
button.needs-attention > label,
.stack-switcher >
button.needs-attention > image, stacksidebar row.needs-attention > label {
  animation: needs_attention 270ms cubic-bezier(0, 0, 0.2, 1) forwards;
  background-repeat: no-repeat;
  background-position: right 3px;
  background-size: 6px 6px;
}

.stack-switcher >
button.needs-attention > label:dir(rtl),
.stack-switcher >
button.needs-attention > image:dir(rtl), stacksidebar row.needs-attention > label:dir(rtl) {
  background-position: left 3px;
}

widget > box.workspace-switcher .linked > button.image-button.workspace-add-button, .linked > button, .linked:not(.vertical) > spinbutton:not(.vertical), .linked:not(.vertical) > entry, .linked:not(.vertical) > combobox > box > button.combo {
  border-radius: 0;
  -gtk-outline-radius: 4px;
}

widget > box.workspace-switcher .linked > button.image-button.workspace-add-button:first-child, .linked > button:first-child, .linked:not(.vertical) > spinbutton:first-child:not(.vertical), .linked:not(.vertical) > entry:first-child, combobox.linked button:nth-child(2):dir(rtl), .linked:not(.vertical) > combobox:first-child > box > button.combo {
  border-top-left-radius: 4px;
  border-bottom-left-radius: 4px;
  margin-right: 0;
}

widget > box.workspace-switcher .linked > button.image-button.workspace-add-button:last-child, .linked > button:last-child, .linked:not(.vertical) > spinbutton:last-child:not(.vertical), .linked:not(.vertical) > entry:last-child, combobox.linked button:nth-child(2):dir(ltr), .linked:not(.vertical) > combobox:last-child > box > button.combo {
  border-top-right-radius: 4px;
  border-bottom-right-radius: 4px;
  margin-left: 0;
}

widget > box.workspace-switcher .linked > button.image-button.workspace-add-button:only-child, .linked > button:only-child, .linked:not(.vertical) > spinbutton:only-child:not(.vertical), .linked:not(.vertical) > entry:only-child, .linked:not(.vertical) > combobox:only-child > box > button.combo {
  border-radius: 4px;
}

widget > box.workspace-switcher .linked.vertical > button.image-button.workspace-add-button, .linked.vertical > button, .linked.vertical > spinbutton:not(.vertical), .linked.vertical > entry, .linked.vertical > combobox > box > button.combo {
  border-radius: 0;
  -gtk-outline-radius: 4px;
}

widget > box.workspace-switcher .linked.vertical > button.image-button.workspace-add-button:first-child, .linked.vertical > button:first-child, .linked.vertical > spinbutton:first-child:not(.vertical), .linked.vertical > entry:first-child, .linked.vertical > combobox:first-child > box > button.combo {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
}

widget > box.workspace-switcher .linked.vertical > button.image-button.workspace-add-button:last-child, .linked.vertical > button:last-child, .linked.vertical > spinbutton:last-child:not(.vertical), .linked.vertical > entry:last-child, .linked.vertical > combobox:last-child > box > button.combo {
  border-bottom-left-radius: 4px;
  border-bottom-right-radius: 4px;
}

widget > box.workspace-switcher .linked.vertical > button.image-button.workspace-add-button:only-child, .linked.vertical > button:only-child, .linked.vertical > spinbutton:only-child:not(.vertical), .linked.vertical > entry:only-child, .linked.vertical > combobox:only-child > box > button.combo {
  border-radius: 4px;
}

/* menu buttons */
modelbutton.flat,
.menuitem.button.flat {
  min-height: 24px;
  padding: 0 8px;
  border-radius: 4px;
  color: inherit;
  transition: none;
}

modelbutton.flat arrow {
  background: none;
}

modelbutton.flat arrow:hover {
  background: none;
}

modelbutton.flat arrow.left {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

modelbutton.flat arrow.right {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

button.color {
  min-height: 24px;
  min-width: 24px;
  padding: 6px;
}

/*************************
 * Check and Radio items *
 *************************/
.view.content-view.check:not(list),
.content-view .tile check:not(list) {
  min-height: 12px;
  min-width: 12px;
  margin: 0;
  padding: 0;
  box-shadow: none;
  background-color: transparent;
  background-image: none;
  -gtk-icon-shadow: 0 1px 1px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
}

.view.content-view.check:not(list):hover, .view.content-view.check:not(list):active,
.content-view .tile check:not(list):hover,
.content-view .tile check:not(list):active {
  -gtk-icon-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23);
}

.view.content-view.check:not(list),
.content-view .tile check:not(list) {
  -gtk-icon-source: -gtk-scaled(url("assets/selectionmode-checkbox-unchecked.png"), url("assets/selectionmode-checkbox-unchecked@2.png"));
}

.view.content-view.check:not(list):checked,
.content-view .tile check:not(list):checked {
  -gtk-icon-source: -gtk-scaled(url("assets/selectionmode-checkbox-checked.png"), url("assets/selectionmode-checkbox-checked@2.png"));
}

checkbutton.text-button,
radiobutton.text-button {
  padding: 2px;
  outline-offset: 0;
}

checkbutton.text-button label:not(:only-child),
radiobutton.text-button label:not(:only-child) {
  margin: 0 8px;
  padding-right: 8px;
}

check row:selected,
radio row:selected {
  background-color: rgba(21, 22, 28, 0.85);
  border-color: rgba(21, 22, 28, 0.85);
}

check row:selected:hover, check row:selected:active,
radio row:selected:hover,
radio row:selected:active {
  color: #FFFFFF;
}

check row:selected:disabled,
radio row:selected:disabled {
  color: rgba(255, 255, 255, 0.3);
}

popover check, popover check:hover, popover check:disabled, popover
radio, popover
radio:hover, popover
radio:disabled {
  box-shadow: none;
  background-image: none;
}

popover check:not(:checked):not(:indeterminate):not(:disabled), popover
radio:not(:checked):not(:indeterminate):not(:disabled) {
  color: rgba(21, 22, 28, 0.54);
}

popover check.left:dir(rtl), popover
radio.left:dir(rtl) {
  margin-left: -8px;
  margin-right: 8px;
}

popover check.right:dir(ltr), popover
radio.right:dir(ltr) {
  margin-left: 8px;
  margin-right: -8px;
}

menu menuitem check, menu menuitem
radio {
  transition: none;
  border: 2px solid rgba(21, 22, 28, 0.85);
  margin: 2px;
  padding: 0;
}

menu menuitem check:dir(ltr), menu menuitem
radio:dir(ltr) {
  margin-right: 8px;
}

menu menuitem check:dir(rtl), menu menuitem
radio:dir(rtl) {
  margin-left: 8px;
}

menu menuitem check:not(:checked):not(:indeterminate):not(:disabled), menu menuitem
radio:not(:checked):not(:indeterminate):not(:disabled) {
  color: rgba(21, 22, 28, 0.54);
}

menu menuitem check, menu menuitem check:hover, menu menuitem check:disabled, menu menuitem
radio, menu menuitem
radio:hover, menu menuitem
radio:disabled {
  box-shadow: none;
}

check,
radio {
  margin: 2px;
  padding: 2px;
  min-width: 12px;
  min-height: 12px;
  background-color: transparent;
  border: 2px solid rgba(21, 22, 28, 0.54);
  transition: 300ms;
  -gtk-icon-source: none;
}

check:checked, check:indeterminate,
radio:checked,
radio:indeterminate {
  background-color: #4D90D6;
  border-color: #4D90D6;
  color: #FFFFFF;
}

check:checked:backdrop, check:indeterminate:backdrop,
radio:checked:backdrop,
radio:indeterminate:backdrop {
  background-color: #a8c4e0;
  border-color: #a8c4e0;
}

check:checked:disabled, check:indeterminate:disabled,
radio:checked:disabled,
radio:indeterminate:disabled {
  background-color: rgba(77, 144, 214, 0.5);
  border-color: rgba(77, 144, 214, 0.5);
}

check:checked:disabled:backdrop, check:indeterminate:disabled:backdrop,
radio:checked:disabled:backdrop,
radio:indeterminate:disabled:backdrop {
  background-color: rgba(56, 60, 74, 0.12);
  border-color: rgba(56, 60, 74, 0.12);
}

check:disabled,
radio:disabled {
  border-color: rgba(21, 22, 28, 0.38);
}

check:checked,
radio:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/scalable/check-active.svg"), url("assets/scalable/check-active@2.svg"));
}

check:indeterminate,
radio:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/scalable/check-indeterminate.svg"), url("assets/scalable/check-indeterminate@2.svg"));
}

radio {
  border-radius: 9999px;
}

check {
  border-radius: 4px;
}

window.background:not(.csd) > widget > checkbutton > check,
menu menuitem check {
  min-width: 10px;
  min-height: 10px;
  background-color: transparent;
  border: 2px solid rgba(21, 22, 28, 0.54);
  border-radius: 4px;
  transition: 300ms;
  -gtk-icon-source: none;
}

window.background:not(.csd) > widget > checkbutton > check:checked, window.background:not(.csd) > widget > checkbutton > check:indeterminate,
menu menuitem check:checked,
menu menuitem check:indeterminate {
  background-color: #4D90D6;
  border-color: #4D90D6;
  color: #FFFFFF;
}

window.background:not(.csd) > widget > checkbutton > check:checked:backdrop, window.background:not(.csd) > widget > checkbutton > check:indeterminate:backdrop,
menu menuitem check:checked:backdrop,
menu menuitem check:indeterminate:backdrop {
  background-color: #a8c4e0;
  border-color: #a8c4e0;
}

window.background:not(.csd) > widget > checkbutton > check:checked:disabled, window.background:not(.csd) > widget > checkbutton > check:indeterminate:disabled,
menu menuitem check:checked:disabled,
menu menuitem check:indeterminate:disabled {
  background-color: rgba(77, 144, 214, 0.5);
  border-color: rgba(77, 144, 214, 0.5);
}

window.background:not(.csd) > widget > checkbutton > check:checked:disabled:backdrop, window.background:not(.csd) > widget > checkbutton > check:indeterminate:disabled:backdrop,
menu menuitem check:checked:disabled:backdrop,
menu menuitem check:indeterminate:disabled:backdrop {
  background-color: rgba(56, 60, 74, 0.12);
  border-color: rgba(56, 60, 74, 0.12);
}

window.background:not(.csd) > widget > checkbutton > check:disabled,
menu menuitem check:disabled {
  border-color: rgba(21, 22, 28, 0.38);
}

window.background:not(.csd) > widget > checkbutton > check:checked,
menu menuitem check:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/scalable/check-active.svg"), url("assets/scalable/check-active@2.svg"));
}

window.background:not(.csd) > widget > checkbutton > check:indeterminate,
menu menuitem check:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/scalable/check-indeterminate.svg"), url("assets/scalable/check-indeterminate@2.svg"));
}

window.background:not(.csd) > widget > radiobutton > radio,
menu menuitem radio {
  min-width: 10px;
  min-height: 10px;
  background-color: transparent;
  border: 2px solid rgba(21, 22, 28, 0.54);
  border-radius: 9999px;
  transition: 300ms;
  -gtk-icon-source: none;
}

window.background:not(.csd) > widget > radiobutton > radio:checked, window.background:not(.csd) > widget > radiobutton > radio:indeterminate,
menu menuitem radio:checked,
menu menuitem radio:indeterminate {
  background-color: #4D90D6;
  border-color: #4D90D6;
  color: #FFFFFF;
}

window.background:not(.csd) > widget > radiobutton > radio:checked:backdrop, window.background:not(.csd) > widget > radiobutton > radio:indeterminate:backdrop,
menu menuitem radio:checked:backdrop,
menu menuitem radio:indeterminate:backdrop {
  background-color: #a8c4e0;
  border-color: #a8c4e0;
}

window.background:not(.csd) > widget > radiobutton > radio:checked:disabled, window.background:not(.csd) > widget > radiobutton > radio:indeterminate:disabled,
menu menuitem radio:checked:disabled,
menu menuitem radio:indeterminate:disabled {
  background-color: rgba(77, 144, 214, 0.5);
  border-color: rgba(77, 144, 214, 0.5);
}

window.background:not(.csd) > widget > radiobutton > radio:checked:disabled:backdrop, window.background:not(.csd) > widget > radiobutton > radio:indeterminate:disabled:backdrop,
menu menuitem radio:checked:disabled:backdrop,
menu menuitem radio:indeterminate:disabled:backdrop {
  background-color: rgba(56, 60, 74, 0.12);
  border-color: rgba(56, 60, 74, 0.12);
}

window.background:not(.csd) > widget > radiobutton > radio:disabled,
menu menuitem radio:disabled {
  border-color: rgba(21, 22, 28, 0.38);
}

window.background:not(.csd) > widget > radiobutton > radio:checked,
menu menuitem radio:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/scalable/check-active.svg"), url("assets/scalable/check-active@2.svg"));
}

window.background:not(.csd) > widget > radiobutton > radio:indeterminate,
menu menuitem radio:indeterminate {
  -gtk-icon-source: -gtk-scaled(url("assets/scalable/check-indeterminate.svg"), url("assets/scalable/check-indeterminate@2.svg"));
}

check:not(:checked):active {
  -gtk-icon-transform: rotate(90deg);
}

radio:not(:checked):active {
  -gtk-icon-transform: scale(0);
}

check:not(:checked):indeterminate:active,
radio:not(:checked):indeterminate:active {
  -gtk-icon-transform: scaleX(-1);
}

check:not(:checked),
radio:not(:checked) {
  transition: all 180ms cubic-bezier(0.4, 0, 0.2, 1), background-size 180ms cubic-bezier(0, 0, 0.2, 1), background-image 360ms cubic-bezier(0, 0, 0.2, 1), -gtk-icon-transform 0;
}

check:not(:checked):active,
radio:not(:checked):active {
  transition: all 180ms cubic-bezier(0.4, 0, 0.2, 1), background-size 0, background-image 0, -gtk-icon-transform 0;
}

treeview.view check,
treeview.view radio {
  padding: 0;
}

treeview.view check:hover,
treeview.view radio:hover {
  box-shadow: inset 0 0 0 9999px alpha(rgba(21, 22, 28, 0.85), 0.05);
}

treeview.view check:hover:disabled,
treeview.view radio:hover:disabled {
  box-shadow: none;
}

treeview.view check:hover:selected,
treeview.view radio:hover:selected {
  box-shadow: inset 0 0 0 9999px alpha(#FFFFFF, 0.05);
}

treeview.view check,
treeview.view radio {
  color: rgba(21, 22, 28, 0.54);
}

treeview.view check:hover, treeview.view check:active,
treeview.view radio:hover,
treeview.view radio:active {
  color: rgba(21, 22, 28, 0.85);
}

treeview.view check:disabled,
treeview.view radio:disabled {
  color: rgba(21, 22, 28, 0.26);
}

treeview.view check:checked, treeview.view check:indeterminate,
treeview.view radio:checked,
treeview.view radio:indeterminate {
  color: #4D90D6;
}

treeview.view check:checked:backdrop, treeview.view check:indeterminate:backdrop,
treeview.view radio:checked:backdrop,
treeview.view radio:indeterminate:backdrop {
  color: #a8c4e0;
}

treeview.view check:checked:disabled, treeview.view check:indeterminate:disabled,
treeview.view radio:checked:disabled,
treeview.view radio:indeterminate:disabled {
  color: rgba(77, 144, 214, 0.5);
}

treeview.view check:selected,
treeview.view radio:selected {
  border-color: #FFFFFF;
}

treeview.view check:selected:hover, treeview.view check:selected:active,
treeview.view radio:selected:hover,
treeview.view radio:selected:active {
  color: rgba(56, 60, 74, 0.85);
}

treeview.view check:selected:disabled,
treeview.view radio:selected:disabled {
  color: rgba(21, 22, 28, 0.38);
}

treeview.view check:selected:checked, treeview.view check:selected:indeterminate,
treeview.view radio:selected:checked,
treeview.view radio:selected:indeterminate {
  background-color: #4D90D6;
  border-color: #FFFFFF;
}

treeview.view check:selected:checked:disabled, treeview.view check:selected:indeterminate:disabled,
treeview.view radio:selected:checked:disabled,
treeview.view radio:selected:indeterminate:disabled {
  color: rgba(77, 144, 214, 0.5);
}

treeview.view radio:checked {
  min-width: 10px;
  min-height: 10px;
  border-radius: 9999px;
}

/*****************
 * Color Chooser *
 *****************/
colorswatch.top {
  border-top-left-radius: 4.5px;
  border-top-right-radius: 4.5px;
}

colorswatch.top overlay {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
}

colorswatch.bottom {
  border-bottom-left-radius: 4.5px;
  border-bottom-right-radius: 4.5px;
}

colorswatch.bottom overlay {
  border-bottom-left-radius: 4px;
  border-bottom-right-radius: 4px;
}

colorswatch.left, colorswatch:first-child:not(.top) {
  border-top-left-radius: 4.5px;
  border-bottom-left-radius: 4.5px;
}

colorswatch.left overlay, colorswatch:first-child:not(.top) overlay {
  border-top-left-radius: 4px;
  border-bottom-left-radius: 4px;
}

colorswatch.right, colorswatch:last-child:not(.bottom) {
  border-top-right-radius: 4.5px;
  border-bottom-right-radius: 4.5px;
}

colorswatch.right overlay, colorswatch:last-child:not(.bottom) overlay {
  border-top-right-radius: 4px;
  border-bottom-right-radius: 4px;
}

colorswatch.dark {
  color: rgba(255, 255, 255, 0.85);
}

colorswatch.light {
  color: rgba(56, 60, 74, 0.85);
}

colorswatch.dark {
  color: rgba(255, 255, 255, 0.85);
}

colorswatch.light {
  color: rgba(56, 60, 74, 0.85);
}

colorswatch:drop(active) {
  box-shadow: none;
}

colorswatch:drop(active).light overlay {
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24), 0 0 0 2px #4D90D6;
}

colorswatch:drop(active).dark overlay {
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24), 0 0 0 2px #4D90D6;
}

colorswatch overlay {
  transition: box-shadow 180ms cubic-bezier(0.4, 0, 0.2, 1);
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
}

colorswatch overlay:hover {
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23);
}

colorswatch#add-color-button {
  border-radius: 4px 4px 0 0;
  color: rgba(255, 255, 255, 0.85);
}

colorswatch#add-color-button:only-child {
  border-radius: 4px;
}

colorswatch#add-color-button overlay {
  background-image: linear-gradient(to right, #fc4138 25%, #ffce51 25%, #ffce51 50%, #437a0d 50%, #437a0d 75%, #4D90D6 75%);
}

colorswatch:disabled {
  opacity: 0.5;
}

colorswatch:disabled overlay {
  box-shadow: none;
}

colorswatch#editor-color-sample {
  border-radius: 4.5px;
}

colorswatch#editor-color-sample overlay {
  border-radius: 4px;
}

colorchooser .popover.osd {
  transition: box-shadow 180ms cubic-bezier(0.4, 0, 0.2, 1);
  border-radius: 4px;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23), inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #FFFFFF;
}

colorchooser .popover.osd:backdrop {
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24), inset 0 1px rgba(255, 255, 255, 0.4);
}

/**********************
 * Window Decorations *
 **********************/
decoration {
  transition: box-shadow 180ms cubic-bezier(0.4, 0, 0.2, 1);
  border-radius: 4px 4px 0 0;
  box-shadow: 0 14px 14px rgba(0, 0, 0, 0.25), 0 10px 5px rgba(0, 0, 0, 0.22), 0 16px 16px transparent;
  margin: 6px;
}

decoration:backdrop {
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23), 0 16px 16px transparent;
}

.maximized decoration,
.fullscreen decoration,
.tiled decoration {
  border-radius: 0;
}

.popup decoration {
  box-shadow: none;
}

.ssd decoration {
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16);
}

.csd.popup decoration {
  border-radius: 4px;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23);
}

tooltip.csd decoration {
  border-radius: 4px;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23);
}

messagedialog.csd decoration {
  border-radius: 4px;
}

.solid-csd decoration {
  margin: 0;
  border-radius: 0;
  box-shadow: none;
  background-color: #383c4a;
}

button.titlebutton {
  padding: 4px;
  min-width: 16px;
  min-height: 16px;
}

/*********
 * Emoji *
 *********/
popover.emoji-picker {
  padding: 0;
}

popover.emoji-picker scrolledwindow {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

button.emoji-section {
  margin-top: -1px;
  padding: 0 8px;
  min-width: 24px;
  min-height: 36px;
  border-radius: 0;
  outline-offset: -6px;
  box-shadow: none;
}

button.emoji-section:hover {
  box-shadow: inset 0 2px rgba(0, 0, 0, 0.26);
}

button.emoji-section:active {
  box-shadow: inset 0 2px #4D90D6;
  background-image: radial-gradient(circle farthest-corner at center, rgba(77, 144, 214, 0.7) 10%, transparent 0%);
}

button.emoji-section:checked {
  box-shadow: inset 0 2px #4D90D6;
  background-color: transparent;
}

button.emoji-section:first-child {
  margin-left: 6px;
}

button.emoji-section:last-child {
  margin-right: 6px;
}

.emoji {
  min-width: 3em;
  min-height: 3em;
  padding: 0;
}

.emoji widget {
  transition: all 180ms cubic-bezier(0.4, 0, 0.2, 1);
}

.emoji widget:hover {
  font-size: larger;
}

/****************
 * Text Entries *
 ****************/
spinbutton:not(.vertical),
entry {
  min-height: 24px;
  min-width: 48px;
  padding: 6px;
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1), box-shadow 180ms cubic-bezier(0.4, 0, 0.2, 1);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), rgba(0, 0, 0, 0.26) 100%, transparent 0%) 0 0 2/0 0 2px;
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04), 0 1px 2px rgba(0, 0, 0, 0.08);
  background-color: #FFFFFF;
  color: rgba(21, 22, 28, 0.85);
}

spinbutton:backdrop:not(.vertical),
entry:backdrop {
  color: rgba(125, 125, 125, 0.895);
}

spinbutton:focus:not(.vertical),
entry:focus {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #4D90D6 100%, transparent 0%) 0 0 2/0 0 2px;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23);
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
  border-bottom: #4D90D6;
}

spinbutton:disabled:not(.vertical),
entry:disabled {
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04), 0 1px 2px rgba(0, 0, 0, 0.08);
  background-color: rgba(255, 255, 255, 0.5);
  color: rgba(21, 22, 28, 0.85);
}

spinbutton:disabled:backdrop:not(.vertical),
entry:disabled:backdrop {
  color: rgba(182, 182, 182, 0.85);
}

spinbutton.flat:not(.vertical), notebook > stack:not(:only-child) entry:not(.search), notebook > stack:not(:only-child) spinbutton:not(.vertical), messagedialog entry, colorchooser .popover.osd spinbutton:not(.vertical), .raven .raven-background spinbutton:not(.vertical), #login_window entry,
entry.flat {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #4D90D6 0%, transparent 0%) 0 0 0/0 0 0px;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.26);
  background-color: transparent;
  color: rgba(21, 22, 28, 0.85);
}

spinbutton.flat:focus:not(.vertical), notebook > stack:not(:only-child) entry:focus:not(.search), notebook > stack:not(:only-child) spinbutton:focus:not(.vertical), messagedialog entry:focus, colorchooser .popover.osd spinbutton:focus:not(.vertical), .raven .raven-background spinbutton:focus:not(.vertical), #login_window entry:focus,
entry.flat:focus {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #4D90D6 100%, transparent 0%) 0 0 2/0 0 2px;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.26);
}

spinbutton.flat:disabled:not(.vertical), notebook > stack:not(:only-child) entry:disabled:not(.search), notebook > stack:not(:only-child) spinbutton:disabled:not(.vertical), messagedialog entry:disabled, colorchooser .popover.osd spinbutton:disabled:not(.vertical), .raven .raven-background spinbutton:disabled:not(.vertical), #login_window entry:disabled,
entry.flat:disabled {
  box-shadow: inset 0 -1px rgba(56, 60, 74, 0.12);
  background-color: transparent;
  color: rgba(21, 22, 28, 0.38);
}

spinbutton:not(.vertical) image,
entry image {
  color: rgba(21, 22, 28, 0.54);
}

spinbutton:not(.vertical) image:hover, spinbutton:not(.vertical) image:active,
entry image:hover,
entry image:active {
  color: rgba(21, 22, 28, 0.85);
}

spinbutton:not(.vertical) image:disabled,
entry image:disabled {
  color: rgba(21, 22, 28, 0.38);
}

spinbutton:not(.vertical) image.left,
entry image.left {
  margin-left: 6px;
  margin-right: 6px;
}

spinbutton:not(.vertical) image.right,
entry image.right {
  margin-left: 6px;
  margin-right: 6px;
}

spinbutton:not(.vertical) undershoot.left,
entry undershoot.left {
  background-color: transparent;
  background-image: none;
  padding-left: 1px;
  background-size: 1px 12px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: left top;
}

spinbutton:not(.vertical) undershoot.right,
entry undershoot.right {
  background-color: transparent;
  background-image: none;
  padding-right: 1px;
  background-size: 1px 12px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: right top;
}

spinbutton.error:not(.vertical),
entry.error {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1), box-shadow 180ms cubic-bezier(0.4, 0, 0.2, 1);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), rgba(0, 0, 0, 0.26) 100%, transparent 0%) 0 0 2/0 0 2px;
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04), 0 1px 2px rgba(0, 0, 0, 0.08);
  background-color: #c10c03;
  color: #FFFFFF;
}

spinbutton.error:backdrop:not(.vertical),
entry.error:backdrop {
  color: rgba(125, 125, 125, 0.895);
}

spinbutton.error:focus:not(.vertical),
entry.error:focus {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #4D90D6 100%, transparent 0%) 0 0 2/0 0 2px;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23);
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
  border-bottom: #4D90D6;
}

spinbutton.error:disabled:not(.vertical),
entry.error:disabled {
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04), 0 1px 2px rgba(0, 0, 0, 0.08);
  background-color: rgba(255, 255, 255, 0.5);
  color: rgba(21, 22, 28, 0.85);
}

spinbutton.error:disabled:backdrop:not(.vertical),
entry.error:disabled:backdrop {
  color: rgba(182, 182, 182, 0.85);
}

spinbutton.error.flat:not(.vertical), notebook > stack:not(:only-child) entry.error:not(.search), notebook > stack:not(:only-child) spinbutton.error:not(.vertical), messagedialog entry.error, colorchooser .popover.osd spinbutton.error:not(.vertical), .raven .raven-background spinbutton.error:not(.vertical), #login_window entry.error,
entry.error.flat {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #c10c03 0%, transparent 0%) 0 0 0/0 0 0px;
  box-shadow: inset 0 -1px #c10c03;
  background-color: transparent;
  color: rgba(21, 22, 28, 0.85);
}

spinbutton.error.flat:focus:not(.vertical), notebook > stack:not(:only-child) entry.error:focus:not(.search), notebook > stack:not(:only-child) spinbutton.error:focus:not(.vertical), messagedialog entry.error:focus, colorchooser .popover.osd spinbutton.error:focus:not(.vertical), .raven .raven-background spinbutton.error:focus:not(.vertical), #login_window entry.error:focus,
entry.error.flat:focus {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #c10c03 100%, transparent 0%) 0 0 2/0 0 2px;
  box-shadow: inset 0 -1px #c10c03;
}

spinbutton.error.flat:disabled:not(.vertical), notebook > stack:not(:only-child) entry.error:disabled:not(.search), notebook > stack:not(:only-child) spinbutton.error:disabled:not(.vertical), messagedialog entry.error:disabled, colorchooser .popover.osd spinbutton.error:disabled:not(.vertical), .raven .raven-background spinbutton.error:disabled:not(.vertical), #login_window entry.error:disabled,
entry.error.flat:disabled {
  box-shadow: inset 0 -1px rgba(56, 60, 74, 0.12);
  background-color: transparent;
  color: rgba(21, 22, 28, 0.38);
}

spinbutton.error:not(.vertical) image,
entry.error image {
  color: rgba(255, 255, 255, 0.7);
}

spinbutton.error:not(.vertical) image:hover, spinbutton.error:not(.vertical) image:active,
entry.error image:hover,
entry.error image:active {
  color: #FFFFFF;
}

spinbutton.error:not(.vertical) image:disabled,
entry.error image:disabled {
  color: rgba(255, 255, 255, 0.5);
}

spinbutton.warning:not(.vertical),
entry.warning {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1), box-shadow 180ms cubic-bezier(0.4, 0, 0.2, 1);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), rgba(0, 0, 0, 0.26) 100%, transparent 0%) 0 0 2/0 0 2px;
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04), 0 1px 2px rgba(0, 0, 0, 0.08);
  background-color: #e0a100;
  color: #FFFFFF;
}

spinbutton.warning:backdrop:not(.vertical),
entry.warning:backdrop {
  color: rgba(125, 125, 125, 0.895);
}

spinbutton.warning:focus:not(.vertical),
entry.warning:focus {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #4D90D6 100%, transparent 0%) 0 0 2/0 0 2px;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23);
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
  border-bottom: #4D90D6;
}

spinbutton.warning:disabled:not(.vertical),
entry.warning:disabled {
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04), 0 1px 2px rgba(0, 0, 0, 0.08);
  background-color: rgba(255, 255, 255, 0.5);
  color: rgba(21, 22, 28, 0.85);
}

spinbutton.warning:disabled:backdrop:not(.vertical),
entry.warning:disabled:backdrop {
  color: rgba(182, 182, 182, 0.85);
}

spinbutton.warning.flat:not(.vertical), notebook > stack:not(:only-child) entry.warning:not(.search), notebook > stack:not(:only-child) spinbutton.warning:not(.vertical), messagedialog entry.warning, colorchooser .popover.osd spinbutton.warning:not(.vertical), .raven .raven-background spinbutton.warning:not(.vertical), #login_window entry.warning,
entry.warning.flat {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #e0a100 0%, transparent 0%) 0 0 0/0 0 0px;
  box-shadow: inset 0 -1px #e0a100;
  background-color: transparent;
  color: rgba(21, 22, 28, 0.85);
}

spinbutton.warning.flat:focus:not(.vertical), notebook > stack:not(:only-child) entry.warning:focus:not(.search), notebook > stack:not(:only-child) spinbutton.warning:focus:not(.vertical), messagedialog entry.warning:focus, colorchooser .popover.osd spinbutton.warning:focus:not(.vertical), .raven .raven-background spinbutton.warning:focus:not(.vertical), #login_window entry.warning:focus,
entry.warning.flat:focus {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #e0a100 100%, transparent 0%) 0 0 2/0 0 2px;
  box-shadow: inset 0 -1px #e0a100;
}

spinbutton.warning.flat:disabled:not(.vertical), notebook > stack:not(:only-child) entry.warning:disabled:not(.search), notebook > stack:not(:only-child) spinbutton.warning:disabled:not(.vertical), messagedialog entry.warning:disabled, colorchooser .popover.osd spinbutton.warning:disabled:not(.vertical), .raven .raven-background spinbutton.warning:disabled:not(.vertical), #login_window entry.warning:disabled,
entry.warning.flat:disabled {
  box-shadow: inset 0 -1px rgba(56, 60, 74, 0.12);
  background-color: transparent;
  color: rgba(21, 22, 28, 0.38);
}

spinbutton.warning:not(.vertical) image,
entry.warning image {
  color: rgba(255, 255, 255, 0.7);
}

spinbutton.warning:not(.vertical) image:hover, spinbutton.warning:not(.vertical) image:active,
entry.warning image:hover,
entry.warning image:active {
  color: #FFFFFF;
}

spinbutton.warning:not(.vertical) image:disabled,
entry.warning image:disabled {
  color: rgba(255, 255, 255, 0.5);
}

spinbutton:not(.vertical) progress,
entry progress {
  margin: -6px;
  border-bottom: 4px solid #4D90D6;
  background-color: rgba(77, 144, 214, 0.1);
  border-radius: 4px 4px 0 0;
}

.linked:not(.vertical) > spinbutton.flat:not(.vertical), notebook > stack:not(:only-child) .linked:not(.vertical) > entry:not(.search), notebook > stack:not(:only-child) .linked:not(.vertical) > spinbutton:not(.vertical), messagedialog .linked:not(.vertical) > entry, colorchooser .popover.osd .linked:not(.vertical) > spinbutton:not(.vertical), .raven .raven-background .linked:not(.vertical) > spinbutton:not(.vertical), #login_window .linked:not(.vertical) > entry,
.linked.vertical > spinbutton.flat:not(.vertical), notebook > stack:not(:only-child)
.linked.vertical > entry:not(.search), notebook > stack:not(:only-child)
.linked.vertical > spinbutton:not(.vertical), messagedialog
.linked.vertical > entry, colorchooser .popover.osd
.linked.vertical > spinbutton:not(.vertical), .raven .raven-background
.linked.vertical > spinbutton:not(.vertical), #login_window
.linked.vertical > entry, .linked:not(.vertical) >
entry.flat,
.linked.vertical >
entry.flat {
  border-radius: 0;
}

treeview entry.flat, treeview entry {
  min-height: 0;
  padding: 2px;
  border-radius: 0;
  background-color: #FFFFFF;
}

treeview entry.flat, treeview entry.flat:focus, treeview entry, treeview entry:focus {
  border-image: none;
  box-shadow: none;
}

.entry-tag, .documents-entry-tag, .photos-entry-tag {
  margin: 4px;
  border-radius: 9999px;
  box-shadow: none;
  background-color: #4D90D6;
  color: #FFFFFF;
}

.entry-tag:hover, .documents-entry-tag:hover, .photos-entry-tag:hover {
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
}

:dir(ltr) .entry-tag, :dir(ltr) .documents-entry-tag, :dir(ltr) .photos-entry-tag {
  margin-left: 8px;
  margin-right: -4px;
  padding-left: 8px;
  padding-right: 4px;
}

:dir(rtl) .entry-tag, :dir(rtl) .documents-entry-tag, :dir(rtl) .photos-entry-tag {
  margin-left: -4px;
  margin-right: 8px;
  padding-left: 4px;
  padding-right: 8px;
}

.entry-tag.button, .button.documents-entry-tag, .button.photos-entry-tag {
  box-shadow: none;
  background-color: transparent;
}

.entry-tag.button:not(:hover):not(:active), .button.documents-entry-tag:not(:hover):not(:active), .button.photos-entry-tag:not(:hover):not(:active) {
  color: rgba(255, 255, 255, 0.7);
}

/*****************
 * GtkSpinButton *
 *****************/
spinbutton:not(.vertical) {
  padding: 6px;
}

notebook > stack:not(:only-child) spinbutton:not(.vertical) entry, notebook > stack:not(:only-child) spinbutton:not(.vertical) entry:focus, notebook > stack:not(:only-child) spinbutton:not(.vertical) entry:disabled,
spinbutton:not(.vertical) entry {
  min-width: 48px;
  margin: 0;
  border-image: none;
  border-radius: 0;
  box-shadow: none;
  background-color: transparent;
  font-size: 52px;
}

spinbutton:not(.vertical) button {
  border: solid 6px transparent;
}

spinbutton:not(.vertical) button.up:dir(ltr), spinbutton:not(.vertical) button.down:dir(rtl) {
  margin-left: -3px;
}

spinbutton:not(.vertical) button.up:dir(rtl), spinbutton:not(.vertical) button.down:dir(ltr) {
  margin-right: -3px;
}

spinbutton.vertical:disabled {
  color: rgba(21, 22, 28, 0.38);
}

spinbutton.vertical:drop(active) {
  box-shadow: none;
}

spinbutton.vertical entry {
  min-height: 24px;
  min-width: 48px;
  padding: 6px;
}

spinbutton.vertical button {
  min-height: 24px;
  min-width: 24px;
  padding: 6px;
}

spinbutton.vertical button.up {
  border-radius: 4px 4px 0 0;
}

spinbutton.vertical button.down {
  border-radius: 0 0 4px 4px;
}

treeview spinbutton:not(.vertical) {
  min-height: 0;
  border-style: none;
  border-radius: 0;
}

treeview spinbutton:not(.vertical) entry {
  min-height: 0;
  padding: 4px 4px;
}

toolbar:not(.inline-toolbar):not(.osd) spinbutton {
  margin: 2px;
}

toolbar:not(.inline-toolbar):not(.osd) .linked spinbutton:not(:first-child) {
  margin-left: 0;
}

toolbar:not(.inline-toolbar):not(.osd) .linked spinbutton:not(:last-child) {
  margin-right: 0;
}

toolbar:not(.inline-toolbar):not(.osd) spinbutton button {
  margin: 0;
}

/**************
 * ComboBoxes *
 **************/
combobox arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  min-height: 16px;
  min-width: 16px;
}

combobox entry ~ button.combo {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1), box-shadow 180ms cubic-bezier(0.4, 0, 0.2, 1);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), rgba(0, 0, 0, 0.26) 100%, transparent 0%) 0 0 2/0 0 2px;
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04), 0 1px 2px rgba(0, 0, 0, 0.08);
  background-color: #FFFFFF;
  color: rgba(21, 22, 28, 0.85);
}

combobox entry ~ button.combo:backdrop {
  color: rgba(125, 125, 125, 0.895);
}

combobox entry ~ button.combo:disabled {
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04), 0 1px 2px rgba(0, 0, 0, 0.08);
  background-color: rgba(255, 255, 255, 0.5);
  color: rgba(21, 22, 28, 0.85);
}

combobox entry ~ button.combo:disabled:backdrop {
  color: rgba(182, 182, 182, 0.85);
}

combobox decoration,
combobox button.combo:checked {
  transition: none;
}

combobox button.combo cellview:dir(ltr) {
  margin-left: 10px;
}

combobox button.combo cellview:dir(rtl) {
  margin-right: 10px;
}

combobox #gtk-combobox-popup-menu {
  padding: 2px 0;
}

combobox #gtk-combobox-popup-menu menuitem {
  min-height: 12px;
  padding: 0 8px;
}

combobox #gtk-combobox-popup-menu > arrow.top {
  margin-top: -2px;
}

combobox #gtk-combobox-popup-menu > arrow.bottom {
  margin-bottom: -6px;
}

combobox:drop(active) {
  box-shadow: none;
}

box.horizontal.linked > entry + button:not(.combo) {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1), box-shadow 180ms cubic-bezier(0.4, 0, 0.2, 1);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), rgba(0, 0, 0, 0.26) 100%, transparent 0%) 0 0 2/0 0 2px;
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04), 0 1px 2px rgba(0, 0, 0, 0.08);
  background-color: #FFFFFF;
  color: rgba(21, 22, 28, 0.85);
}

box.horizontal.linked > entry + button:not(.combo):backdrop {
  color: rgba(125, 125, 125, 0.895);
}

box.horizontal.linked > entry + button:not(.combo):disabled {
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04), 0 1px 2px rgba(0, 0, 0, 0.08);
  background-color: rgba(255, 255, 255, 0.5);
  color: rgba(21, 22, 28, 0.85);
}

box.horizontal.linked > entry + button:not(.combo):disabled:backdrop {
  color: rgba(182, 182, 182, 0.85);
}

notebook > stack:not(:only-child) button.combo, .raven .raven-background button.combo, #login_window #user_combobox button {
  border-radius: 0;
  background-image: none;
  font-weight: inherit;
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #4D90D6 0%, transparent 0%) 0 0 0/0 0 0px;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.26);
  background-color: transparent;
  color: rgba(21, 22, 28, 0.85);
}

notebook > stack:not(:only-child) button.combo:hover, .raven .raven-background button.combo:hover, #login_window #user_combobox button:hover {
  box-shadow: inset 0 -2px rgba(21, 22, 28, 0.38);
}

notebook > stack:not(:only-child) button.combo:checked, .raven .raven-background button.combo:checked, #login_window #user_combobox button:checked {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #4D90D6 100%, transparent 0%) 0 0 2/0 0 2px;
}

notebook > stack:not(:only-child) button.combo:disabled, .raven .raven-background button.combo:disabled, #login_window #user_combobox button:disabled {
  color: rgba(21, 22, 28, 0.38);
}

toolbar:not(.inline-toolbar):not(.osd) entry {
  margin: 2px;
}

toolbar:not(.inline-toolbar):not(.osd) .linked entry:not(:first-child) {
  margin-left: 0;
}

toolbar:not(.inline-toolbar):not(.osd) .linked entry:not(:last-child) {
  margin-right: 0;
}

toolbar:not(.inline-toolbar):not(.osd) spinbutton entry {
  margin: 0;
}

headerbar entry {
  margin-top: 6px;
  margin-bottom: 6px;
}

popover.emoji-picker entry {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
  box-shadow: none;
}

/*************
 * Expanders *
 *************/
expander arrow {
  transition: all 180ms cubic-bezier(0.4, 0, 0.2, 1);
  min-width: 16px;
  min-height: 16px;
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  -gtk-icon-transform: rotate(-90deg);
  color: rgba(21, 22, 28, 0.54);
}

expander arrow:dir(rtl) {
  -gtk-icon-transform: rotate(90deg);
}

expander arrow:checked {
  -gtk-icon-transform: unset;
}

expander arrow:hover, expander arrow:active {
  color: rgba(21, 22, 28, 0.85);
}

expander arrow:disabled {
  color: rgba(21, 22, 28, 0.26);
}

expander arrow:selected {
  color: rgba(255, 255, 255, 0.7);
}

expander arrow:selected:hover, expander arrow:selected:active {
  color: #FFFFFF;
}

expander arrow:selected:disabled {
  color: rgba(255, 255, 255, 0.3);
}

/**********
 * Frames *
 **********/
frame > border,
.frame {
  margin: 0;
  padding: 0;
  border: 1px solid rgba(0, 0, 0, 0.12);
  border-radius: 0;
  box-shadow: none;
}

frame > border.flat,
.frame.flat,
frame.flat > border {
  border-style: none;
}

actionbar > revealer > box {
  padding: 6px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

scrolledwindow viewport.frame {
  border-style: none;
}

overshoot.top {
  background-image: -gtk-gradient(radial, center top, 0, center top, 0.75, to(rgba(77, 144, 214, 0.3)), to(transparent));
  background-repeat: no-repeat;
  background-position: center top;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

overshoot.bottom {
  background-image: -gtk-gradient(radial, center bottom, 0, center bottom, 0.75, to(rgba(77, 144, 214, 0.3)), to(transparent));
  background-repeat: no-repeat;
  background-position: center bottom;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

overshoot.left {
  background-image: -gtk-gradient(radial, left center, 0, left center, 0.75, to(rgba(77, 144, 214, 0.3)), to(transparent));
  background-repeat: no-repeat;
  background-position: left center;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

overshoot.right {
  background-image: -gtk-gradient(radial, right center, 0, right center, 0.75, to(rgba(77, 144, 214, 0.3)), to(transparent));
  background-repeat: no-repeat;
  background-position: right center;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

undershoot.top {
  background-color: transparent;
  background-image: none;
  padding-top: 1px;
  background-size: 12px 1px;
  background-repeat: repeat-x;
  background-origin: content-box;
  background-position: left top;
}

undershoot.bottom {
  background-color: transparent;
  background-image: none;
  padding-bottom: 1px;
  background-size: 12px 1px;
  background-repeat: repeat-x;
  background-origin: content-box;
  background-position: left bottom;
}

undershoot.left {
  background-color: transparent;
  background-image: none;
  padding-left: 1px;
  background-size: 1px 12px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: left top;
}

undershoot.right {
  background-color: transparent;
  background-image: none;
  padding-right: 1px;
  background-size: 1px 12px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: right top;
}

junction {
  border-style: solid none none solid;
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #FFFFFF;
}

junction:dir(rtl) {
  border-style: solid solid none none;
}

separator {
  min-width: 1px;
  min-height: 1px;
  background-color: transparent;
}


button.font separator,
button.file separator, .tweak-categories separator {
  min-width: 0;
  min-height: 0;
  background-color: transparent;
}

/***************
 * Header bars *
 ***************/
.titlebar:not(headerbar),
headerbar {
  transition: background-color 180ms cubic-bezier(0, 0, 0.2, 1), color 270ms cubic-bezier(0, 0, 0.2, 1);
  min-height: 40px;
  padding: 0 6px;
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24), inset 0 1px rgba(255, 255, 255, 0.1);
  background-color: #383c4a;
  color: #FFFFFF;
}

.titlebar:disabled:not(headerbar) :not(button) > label,
headerbar:disabled :not(button) > label {
  color: rgba(255, 255, 255, 0.3);
}

.titlebar:backdrop:not(headerbar),
headerbar:backdrop {
  color: rgba(255, 255, 255, 0.6);
  background-color: #444856;
}

.titlebar:backdrop:disabled:not(headerbar) :not(button) > label,
headerbar:backdrop:disabled :not(button) > label {
  color: rgba(255, 255, 255, 0.2);
}

.titlebar:not(headerbar) .title,
headerbar .title {
  padding: 0 12px;
  font-weight: bold;
}

.titlebar:not(headerbar) .subtitle,
headerbar .subtitle {
  padding: 0 12px;
  font-size: smaller;
}

.titlebar:not(headerbar) separator,
headerbar separator {
  background-color: #383c4a;
  margin: 0 12px;
}

.titlebar:not(headerbar) separator:backdrop,
headerbar separator:backdrop {
  background-color: #444856;
}

.titlebar:not(headerbar) separator:first-child, .titlebar:not(headerbar) separator:last-child,
headerbar separator:first-child,
headerbar separator:last-child {
  margin: 0;
  min-width: 0;
  padding: 0;
}

.titlebar:not(headerbar) .linked:not(.vertical) > entry:not(.flat),
headerbar .linked:not(.vertical) > entry:not(.flat) {
  border-radius: 4px;
}

.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action),
headerbar button:not(.suggested-action):not(.destructive-action) {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #4D90D6 0%, transparent 0%) 0 0 0/0 0 0px;
  color: rgba(255, 255, 255, 0.6);
}

.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action).titlebutton,
headerbar button:not(.suggested-action):not(.destructive-action).titlebutton {
  padding: 4px;
  min-width: 16px;
  min-height: 16px;
}

.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action).titlebutton.close,
headerbar button:not(.suggested-action):not(.destructive-action).titlebutton.close {
  background-color: #a34f6d;
  color: #FFFFFF;
}

.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action).titlebutton.close:backdrop,
headerbar button:not(.suggested-action):not(.destructive-action).titlebutton.close:backdrop {
  background-color: rgba(255, 255, 255, 0.12);
  color: #FFFFFF;
}

.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action).titlebutton.appmenu > image,
headerbar button:not(.suggested-action):not(.destructive-action).titlebutton.appmenu > image {
  padding: 6px;
  min-width: 16px;
  min-height: 16px;
}

.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):hover, .titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):active,
headerbar button:not(.suggested-action):not(.destructive-action):hover,
headerbar button:not(.suggested-action):not(.destructive-action):active {
  color: #FFFFFF;
}

.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):disabled,
headerbar button:not(.suggested-action):not(.destructive-action):disabled {
  color: rgba(255, 255, 255, 0.2);
}

.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):checked,
headerbar button:not(.suggested-action):not(.destructive-action):checked {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #4D90D6 100%, transparent 0%) 0 0 2/0 0 2px;
  color: #FFFFFF;
}

.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):checked:disabled,
headerbar button:not(.suggested-action):not(.destructive-action):checked:disabled {
  color: rgba(255, 255, 255, 0.3);
}

.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):checked, .titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):checked:disabled,
headerbar button:not(.suggested-action):not(.destructive-action):checked,
headerbar button:not(.suggested-action):not(.destructive-action):checked:disabled {
  background-color: transparent;
}

.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):backdrop,
headerbar button:not(.suggested-action):not(.destructive-action):backdrop {
  color: rgba(255, 255, 255, 0.5);
}

.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):backdrop:hover, .titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):backdrop:active,
headerbar button:not(.suggested-action):not(.destructive-action):backdrop:hover,
headerbar button:not(.suggested-action):not(.destructive-action):backdrop:active {
  color: rgba(255, 255, 255, 0.6);
}

.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):backdrop:disabled,
headerbar button:not(.suggested-action):not(.destructive-action):backdrop:disabled {
  color: rgba(255, 255, 255, 0.2);
}

.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):backdrop:checked,
headerbar button:not(.suggested-action):not(.destructive-action):backdrop:checked {
  color: rgba(255, 255, 255, 0.6);
}

.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):backdrop:checked:disabled,
headerbar button:not(.suggested-action):not(.destructive-action):backdrop:checked:disabled {
  color: rgba(255, 255, 255, 0.2);
}

.titlebar:not(headerbar) button.suggested-action:disabled, .titlebar:not(headerbar) button.destructive-action:disabled,
headerbar button.suggested-action:disabled,
headerbar button.destructive-action:disabled {
  background-color: rgba(255, 255, 255, 0.12);
  color: rgba(255, 255, 255, 0.3);
}

.selection-mode.titlebar:not(headerbar),
headerbar.selection-mode {
  transition: background-color 250ms 270ms, color 270ms cubic-bezier(0, 0, 0.2, 1);
  animation: header_ripple_effect 270ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24), inset 0 1px rgba(255, 255, 255, 0.2);
  background-color: #4D90D6;
  color: #FFFFFF;
}

.selection-mode.titlebar:backdrop:not(headerbar),
headerbar.selection-mode:backdrop {
  color: rgba(255, 255, 255, 0.7);
}

.selection-mode.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action),
headerbar.selection-mode button:not(.suggested-action):not(.destructive-action) {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), currentColor 0%, transparent 0%) 0 0 0/0 0 0px;
  color: #FFFFFF;
}

.selection-mode.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):disabled,
headerbar.selection-mode button:not(.suggested-action):not(.destructive-action):disabled {
  color: rgba(255, 255, 255, 0.5);
}

.selection-mode.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):checked,
headerbar.selection-mode button:not(.suggested-action):not(.destructive-action):checked {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #4D90D6 100%, transparent 0%) 0 0 2/0 0 2px;
  color: #FFFFFF;
}

.selection-mode.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):checked:disabled,
headerbar.selection-mode button:not(.suggested-action):not(.destructive-action):checked:disabled {
  color: rgba(255, 255, 255, 0.5);
}

.selection-mode.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):backdrop,
headerbar.selection-mode button:not(.suggested-action):not(.destructive-action):backdrop {
  color: rgba(255, 255, 255, 0.7);
}

.selection-mode.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):backdrop:disabled,
headerbar.selection-mode button:not(.suggested-action):not(.destructive-action):backdrop:disabled {
  color: rgba(255, 255, 255, 0.3);
}

.selection-mode.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):backdrop:checked,
headerbar.selection-mode button:not(.suggested-action):not(.destructive-action):backdrop:checked {
  color: rgba(255, 255, 255, 0.7);
}

.selection-mode.titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):backdrop:checked:disabled,
headerbar.selection-mode button:not(.suggested-action):not(.destructive-action):backdrop:checked:disabled {
  color: rgba(255, 255, 255, 0.3);
}

.selection-mode.titlebar:not(headerbar) .selection-menu,
headerbar.selection-mode .selection-menu {
  padding-left: 16px;
  padding-right: 16px;
}

.selection-mode.titlebar:not(headerbar) .selection-menu arrow,
headerbar.selection-mode .selection-menu arrow {
  -GtkArrow-arrow-scaling: 1;
}

.selection-mode.titlebar:not(headerbar) .selection-menu .arrow,
headerbar.selection-mode .selection-menu .arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

.tiled .titlebar:not(headerbar),
.maximized .titlebar:not(headerbar),
.fullscreen .titlebar:not(headerbar),
.tiled-bottom .titlebar:not(headerbar),
.tiled-top .titlebar:not(headerbar),
.tiled-left .titlebar:not(headerbar),
.tiled-right .titlebar:not(headerbar), .tiled
headerbar,
.maximized
headerbar,
.fullscreen
headerbar,
.tiled-bottom
headerbar,
.tiled-top
headerbar,
.tiled-left
headerbar,
.tiled-right
headerbar {
  border-radius: 0;
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
}

.default-decoration.titlebar:not(headerbar),
headerbar.default-decoration {
  min-height: 24px;
  padding: 6px;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
}

.tiled .default-decoration.titlebar:not(headerbar),
.maximized .default-decoration.titlebar:not(headerbar),
.fullscreen .default-decoration.titlebar:not(headerbar), .tiled
headerbar.default-decoration,
.maximized
headerbar.default-decoration,
.fullscreen
headerbar.default-decoration {
  box-shadow: none;
}

.default-decoration.titlebar:not(headerbar) button.titlebutton,
headerbar.default-decoration button.titlebutton {
  min-height: 24px;
  min-width: 24px;
  margin: 0;
  padding: 0;
}

.background:not(.csd) .default-decoration.titlebar:not(headerbar) button.titlebutton:active, .background:not(.csd)
headerbar.default-decoration button.titlebutton:active {
  background-size: 1000% 1000%;
}

headerbar spinbutton,
headerbar button {
  margin-top: 6px;
  margin-bottom: 6px;
}

headerbar switch {
  margin-top: 12px;
  margin-bottom: 12px;
}

headerbar spinbutton button {
  margin-top: 0;
  margin-bottom: 0;
}

.background:not(.tiled):not(.tiled-bottom):not(.tiled-top):not(.tiled-left):not(.tiled-right):not(.maximized):not(.fullscreen):not(.solid-csd) .titlebar {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
}

window:not(.tiled):not(.tiled-bottom):not(.tiled-top):not(.tiled-left):not(.tiled-right):not(.maximized):not(.fullscreen):not(.solid-csd) separator:first-child + headerbar,
window:not(.tiled):not(.tiled-bottom):not(.tiled-top):not(.tiled-left):not(.tiled-right):not(.maximized):not(.fullscreen):not(.solid-csd) headerbar:first-child {
  border-top-left-radius: 4px;
}

window:not(.tiled):not(.tiled-bottom):not(.tiled-top):not(.tiled-left):not(.tiled-right):not(.maximized):not(.fullscreen):not(.solid-csd) headerbar:last-child {
  border-top-right-radius: 4px;
}

window:not(.tiled):not(.tiled-bottom):not(.tiled-top):not(.tiled-left):not(.tiled-right):not(.maximized):not(.fullscreen):not(.solid-csd) stack headerbar:first-child, window:not(.tiled):not(.tiled-bottom):not(.tiled-top):not(.tiled-left):not(.tiled-right):not(.maximized):not(.fullscreen):not(.solid-csd) stack headerbar:last-child {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
}

window.tiled headerbar,
window.maximized headerbar,
window.fullscreen headerbar,
window.tiled-bottom headerbar,
window.tiled-top headerbar,
window.tiled-left headerbar,
window.tiled-right headerbar {
  border-radius: 0;
}

window.csd > .titlebar:not(headerbar) {
  padding: 0;
  background-color: transparent;
  background-image: none;
  border-style: none;
  box-shadow: none;
}

.titlebar:not(headerbar) > separator {
  background: #383c4a;
  color: #383c4a;
  border: none;
  padding: 0;
  margin: 0;
}

.titlebar:not(headerbar) > separator:backdrop {
  background-color: #444856;
  color: #444856;
  border-color: #444856;
}

.titlebar:not(headerbar) button.titlebutton {
  padding: 4px;
  min-width: 16px;
  min-height: 16px;
}

.titlebar:not(headerbar):backdrop {
  background-color: #444856;
}

/**************
 * GtkInfoBar *
 **************/
infobar {
  border-style: none;
}

infobar.info {
  background-color: #437a0d;
}

infobar.question {
  background-color: #4D90D6;
}

infobar.warning {
  background-color: #ffce51;
}

infobar.error {
  background-color: #fc4138;
}

infobar.info > label, infobar.info, infobar.question > label, infobar.question, infobar.warning > label, infobar.warning, infobar.error > label, infobar.error {
  color: #000000;
}

infobar.info button, infobar.question button, infobar.warning button, infobar.error button {
  color: rgba(21, 22, 28, 0.85);
  background-color: white;
}

infobar.info button > label,
infobar.info button > image, infobar.question button > label,
infobar.question button > image, infobar.warning button > label,
infobar.warning button > image, infobar.error button > label,
infobar.error button > image {
  color: rgba(21, 22, 28, 0.85);
}

/*************
 * Level Bar *
 *************/
levelbar.horizontal {
  border-radius: 4px;
}

levelbar.horizontal block {
  min-height: 4px;
}

levelbar.horizontal.discrete block {
  min-width: 24px;
}

levelbar.horizontal.discrete block:not(:last-child) {
  margin-right: 2px;
}

levelbar.vertical {
  border-radius: 4px;
}

levelbar.vertical block {
  min-width: 4px;
}

levelbar.vertical.discrete block {
  min-height: 24px;
}

levelbar.vertical.discrete block:not(:last-child) {
  margin-bottom: 2px;
}

levelbar trough {
  padding: 2px;
  border-radius: 9999px;
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  background-color: #FFFFFF;
  border-radius: 4px;
}

levelbar trough:disabled {
  background-color: white;
}

levelbar block {
  border-radius: 4px;
}

levelbar block.low {
  background-color: #e0a100;
}

levelbar block.high, levelbar block:not(.empty) {
  background-color: #4D90D6;
}

levelbar block.high:backdrop, levelbar block:not(.empty):backdrop {
  background-color: #a8c4e0;
}

levelbar block.full {
  background-color: #132304;
}

levelbar block.empty {
  background-color: rgba(56, 60, 74, 0.12);
}

/*********
 * Lists *
 *********/
list {
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #FFFFFF;
}

list row {
  padding: 2px;
}

list row:selected {
  background-color: #4D90D6;
}

list row:selected:backdrop {
  background-color: #a8c4e0;
}

row.activatable, .view, treeview.view header button, .budgie-menu button {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1), background-color 0, color 0, background-size 450ms cubic-bezier(0, 0, 0.2, 1), background-image 900ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: inset 0 0 0 9999px transparent;
  background-image: radial-gradient(circle farthest-corner at center, transparent 10%, transparent 0%);
  background-repeat: no-repeat;
  background-position: center;
  background-size: 1000% 1000%;
}

row.activatable button, .view button, treeview.view header button button, .budgie-menu button button {
  color: rgba(21, 22, 28, 0.85);
}

row.activatable button > label, .view button > label, treeview.view header button button > label, .budgie-menu button button > label {
  color: rgba(21, 22, 28, 0.85);
}

row.activatable:hover, .view:hover, treeview.view header button:hover, .budgie-menu button:hover {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1), background-color 0, color 0, box-shadow 0, background-size 450ms cubic-bezier(0, 0, 0.2, 1), background-image 900ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: inset 0 0 0 9999px alpha(currentColor, 0.05);
}

row.activatable.has-open-popup, .has-open-popup.view, treeview.view header button.has-open-popup, .budgie-menu button.has-open-popup, row.activatable:active, .view:active, treeview.view header button:active, .budgie-menu button:active {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1), background-color 0, color 0, background-size 0, background-image 0;
  animation: ripple_effect 270ms cubic-bezier(0, 0, 0.2, 1) forwards;
  box-shadow: inset 0 0 0 9999px alpha(currentColor, 0.15);
  background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor, 0.15) 10%, transparent 0%);
  background-size: 0% 0%;
}

row:selected:backdrop {
  background-color: #a8c4e0;
}

/*********
 * Menus *
 *********/
menubar,
.menubar {
  -GtkWidget-window-dragging: true;
  padding: 0;
  background-color: #383c4a;
}

menubar:backdrop,
.menubar:backdrop {
  background-color: #444856;
}

menubar > menuitem,
.menubar > menuitem {
  transition: all 180ms cubic-bezier(0.4, 0, 0.2, 1);
  min-height: 16px;
  padding: 4px 8px;
  color: rgba(255, 255, 255, 0.6);
}

menubar > menuitem:hover,
.menubar > menuitem:hover {
  transition: none;
  background-color: rgba(255, 255, 255, 0.12);
  color: #FFFFFF;
}

menubar > menuitem:disabled,
.menubar > menuitem:disabled {
  color: rgba(255, 255, 255, 0.2);
}

menubar > menuitem label:disabled,
.menubar > menuitem label:disabled {
  color: inherit;
}

.csd.popup {
  background-color: transparent;
}

menu,
.menu,
.context-menu {
  margin: 4px;
  padding: 4px;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #FFFFFF;
  border: 1px solid rgba(0, 0, 0, 0.12);
}

.csd menu, .csd
.menu, .csd
.context-menu {
  border: none;
  border-radius: 4px;
}

menu menuitem,
.menu menuitem,
.context-menu menuitem {
  transition: none;
  min-height: 16px;
  min-width: 32px;
  padding: 4px 8px;
  font: initial;
  text-shadow: none;
}

menu menuitem:hover,
.menu menuitem:hover,
.context-menu menuitem:hover {
  transition: none;
  background-color: rgba(56, 60, 74, 0.12);
}

menu menuitem:disabled,
.menu menuitem:disabled,
.context-menu menuitem:disabled {
  color: rgba(21, 22, 28, 0.38);
}

menu menuitem arrow,
.menu menuitem arrow,
.context-menu menuitem arrow {
  min-height: 16px;
  min-width: 16px;
}

menu menuitem arrow:dir(ltr),
.menu menuitem arrow:dir(ltr),
.context-menu menuitem arrow:dir(ltr) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
  margin-left: 8px;
}

menu menuitem arrow:dir(rtl),
.menu menuitem arrow:dir(rtl),
.context-menu menuitem arrow:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
  margin-right: 8px;
}

menu menuitem label:dir(rtl), menu menuitem label:dir(ltr),
.menu menuitem label:dir(rtl),
.menu menuitem label:dir(ltr),
.context-menu menuitem label:dir(rtl),
.context-menu menuitem label:dir(ltr) {
  color: inherit;
}

menu > arrow,
.menu > arrow,
.context-menu > arrow {
  min-height: 16px;
  min-width: 16px;
  padding: 4px;
  background-color: #FFFFFF;
  color: rgba(21, 22, 28, 0.54);
}

menu > arrow.top,
.menu > arrow.top,
.context-menu > arrow.top {
  margin-top: -4px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  border-radius: 4px 4px 0 0;
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

menu > arrow.bottom,
.menu > arrow.bottom,
.context-menu > arrow.bottom {
  margin-bottom: -12px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
  border-radius: 0 0 4px 4px;
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

menu > arrow:hover,
.menu > arrow:hover,
.context-menu > arrow:hover {
  background-image: image(rgba(56, 60, 74, 0.12));
  color: rgba(21, 22, 28, 0.85);
}

menu > arrow:disabled,
.menu > arrow:disabled,
.context-menu > arrow:disabled {
  border-color: transparent;
  background-color: transparent;
  color: transparent;
}

menu separator,
.menu separator,
.context-menu separator {
  margin: 4px 0;
}

menuitem accelerator {
  color: rgba(21, 22, 28, 0.54);
}

.popup:not(.csd) menu menuitem {
  color: #3b4a5d;
}

.popup:not(.csd) menu menuitem:hover {
  background-color: #eceff3;
}

.popup:not(.csd) menu menuitem:disabled {
  color: #d3dae3;
}

.popup:not(.csd) menu accelerator {
  color: #a7b5c7;
}

/*********
 * Links *
 *********/
*:link, button:link,
button:visited, *:link:hover, button:hover:link,
button:hover:visited, *:link:active, button:active:link,
button:active:visited {
  color: #4D90D6;
}

*:link:visited,
button:visited, *:link:visited:hover,
button:visited:hover, *:link:visited:active,
button:visited:active {
  color: #2767aa;
}

infobar.info *:link, infobar.info button:link, infobar.info
button:visited, infobar.question *:link, infobar.question button:link, infobar.question
button:visited, infobar.warning *:link, infobar.warning button:link, infobar.warning
button:visited, infobar.error *:link, infobar.error button:link, infobar.error
button:visited, *:link:selected, .selection-mode.titlebar:not(headerbar) .subtitle:link,
headerbar.selection-mode .subtitle:link, button:selected:link,
button:selected:visited,
*:selected *:link,
*:selected button:link,
*:selected
button:visited {
  color: #FFFFFF;
}

button:link > label,
button:visited > label {
  text-decoration-line: underline;
}

/********
 * Misc *
 ********/
.content-view {
  background-color: white;
}

/*********************
 * Spinner Animation *
 *********************/
@keyframes spin {
  to {
    -gtk-icon-transform: rotate(1turn);
  }
}

spinner {
  background: none;
  opacity: 0;
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
}

spinner:checked {
  opacity: 1;
  animation: spin 1s linear infinite;
}

spinner:checked:disabled {
  opacity: 0.5;
}

/****************
 * Print dialog *
*****************/
printdialog paper {
  padding: 0;
  border: 1px solid rgba(0, 0, 0, 0.12);
  background-color: #FFFFFF;
  color: rgba(21, 22, 28, 0.85);
}

printdialog .dialog-action-box {
  margin: 12px;
}

/*********************
 * App Notifications *
 *********************/
.app-notification {
  margin: 8px;
}

.app-notification.frame,
.app-notification border {
  border-style: none;
}

/************
 * Calendar *
 ************/
calendar {
  padding: 2px;
  border: 1px solid rgba(0, 0, 0, 0.12);
  color: rgba(21, 22, 28, 0.85);
}

calendar:disabled {
  color: rgba(21, 22, 28, 0.38);
}

calendar:selected {
  border-radius: 4px;
}

calendar.header {
  border-style: none none solid;
  border-radius: 0;
}

calendar.highlight {
  color: rgba(21, 22, 28, 0.54);
  font-weight: 500;
}

calendar:indeterminate {
  color: rgba(21, 22, 28, 0.26);
}

/**********************
 * Touch Copy & Paste *
 **********************/
cursor-handle {
  border-radius: 9999px;
  background-color: #4D90D6;
  background-image: none;
}

cursor-handle.top:dir(ltr), cursor-handle.bottom:dir(rtl) {
  padding-left: 6px;
  border-top-right-radius: 0;
}

cursor-handle.bottom:dir(ltr), cursor-handle.top:dir(rtl) {
  padding-right: 6px;
  border-top-left-radius: 0;
}

cursor-handle.insertion-cursor:dir(ltr), cursor-handle.insertion-cursor:dir(rtl) {
  -GtkWidget-text-handle-width: 24;
  -GtkWidget-text-handle-height: 30;
  -gtk-icon-source: -gtk-scaled(url("assets/scale-horz-marks-before-slider.png"), url("assets/scale-horz-marks-before-slider@2.png"));
}

.context-menu {
  font: initial;
}

.keycap {
  min-width: 24px;
  min-height: 24px;
  margin-top: 2px;
  padding-bottom: 2px;
  padding-left: 8px;
  padding-right: 8px;
  border: solid 1px rgba(0, 0, 0, 0.12);
  border-radius: 3px;
  box-shadow: inset 0 -2px rgba(0, 0, 0, 0.12);
  background-color: #FFFFFF;
  color: rgba(21, 22, 28, 0.85);
  font-size: smaller;
}

/*
:not(decoration):not(window):drop(active) { // FIXME needs to be done widget by widget, this wildcard should really die
  transition: $longer_transition;
  box-shadow: $shadow_1, inset 0 0 0 2px $accent_color;
  caret-color: $accent_color;
}*/
stackswitcher button.text-button {
  min-width: 100px;
}

stackswitcher button.circular,
stackswitcher button.text-button.circular {
  min-width: 24px;
  min-height: 24px;
  padding: 0;
}

/********
 * Misc *
 ********/
.content-view {
  background-color: white;
}

.view selection, .view:selected, flowbox flowboxchild:selected, modelbutton.flat:selected,
.menuitem.button.flat:selected, spinbutton:not(.vertical) selection,
entry selection, row:selected, calendar:selected, popover.background.menu button:checked,
popover.background button.model:checked, text:selected, window.background.chromium > textview.view text:selected, window.background.chromium > textview.view text:selected:focus,
window.background.chromium > textview.view text selection,
window.background.chromium > textview.view text selection:focus, .budgie-menu button:checked {
  background-color: #4D90D6;
  color: #FFFFFF;
}

.view selection:backdrop, .view:backdrop:selected, flowbox flowboxchild:backdrop:selected, modelbutton.flat:backdrop:selected,
.menuitem.button.flat:backdrop:selected, spinbutton:not(.vertical) selection:backdrop,
entry selection:backdrop, row:backdrop:selected, calendar:backdrop:selected, popover.background.menu button:backdrop:checked,
popover.background button.model:backdrop:checked, text:backdrop:selected, window.background.chromium > textview.view text:backdrop:selected,
window.background.chromium > textview.view text selection:backdrop, .budgie-menu button:backdrop:checked {
  background-color: #a8c4e0;
}

row:selected label, label:selected, .view selection, .view:selected, flowbox flowboxchild:selected, modelbutton.flat:selected,
.menuitem.button.flat:selected, spinbutton:not(.vertical) selection,
entry selection, row:selected, calendar:selected, popover.background.menu button:checked,
popover.background button.model:checked, text:selected, window.background.chromium > textview.view text:selected, window.background.chromium > textview.view text:selected:focus,
window.background.chromium > textview.view text selection,
window.background.chromium > textview.view text selection:focus, .budgie-menu button:checked {
  color: #FFFFFF;
}

row:selected label:disabled, label:disabled:selected, .view selection:disabled, .view:disabled:selected, flowbox flowboxchild:disabled:selected, label:disabled selection, modelbutton.flat:disabled:selected,
.menuitem.button.flat:disabled:selected, spinbutton:not(.vertical) selection:disabled,
entry selection:disabled, row:disabled:selected, calendar:disabled:selected, popover.background.menu button:disabled:checked,
popover.background button.model:disabled:checked, text:disabled:selected, window.background.chromium > textview.view text:disabled:selected,
window.background.chromium > textview.view text selection:disabled, .budgie-menu button:disabled:checked {
  color: rgba(255, 255, 255, 0.5);
}

.monospace {
  font-family: monospace;
}

/*************
 * Notebooks *
 *************/
notebook > header {
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: white;
  background-clip: border-box;
}

notebook > header.top {
  border-bottom-style: solid;
}

notebook > header.top > tabs {
  margin-bottom: -1px;
}

notebook > header.top > tabs > tab:hover {
  box-shadow: inset 0 -2px rgba(0, 0, 0, 0.26);
}

notebook > header.top > tabs > tab:checked {
  box-shadow: inset 0 -2px #4D90D6;
}

notebook > header.bottom {
  border-top-style: solid;
}

notebook > header.bottom > tabs {
  margin-top: -1px;
}

notebook > header.bottom > tabs > tab:hover {
  box-shadow: inset 0 2px rgba(0, 0, 0, 0.26);
}

notebook > header.bottom > tabs > tab:checked {
  box-shadow: inset 0 2px #4D90D6;
}

notebook > header.left {
  border-right-style: solid;
}

notebook > header.left > tabs {
  margin-right: -1px;
}

notebook > header.left > tabs > tab:hover {
  box-shadow: inset -2px 0 rgba(0, 0, 0, 0.26);
}

notebook > header.left > tabs > tab:checked {
  box-shadow: inset -2px 0 #4D90D6;
}

notebook > header.right {
  border-left-style: solid;
}

notebook > header.right > tabs {
  margin-left: -1px;
}

notebook > header.right > tabs > tab:hover {
  box-shadow: inset 2px 0 rgba(0, 0, 0, 0.26);
}

notebook > header.right > tabs > tab:checked {
  box-shadow: inset 2px 0 #4D90D6;
}

notebook > header.top > tabs > arrow {
  border-top-style: none;
}

notebook > header.bottom > tabs > arrow {
  border-bottom-style: none;
}

notebook > header.top > tabs > arrow, notebook > header.bottom > tabs > arrow {
  padding-left: 6px;
  padding-right: 6px;
}

notebook > header.top > tabs > arrow.down, notebook > header.bottom > tabs > arrow.down {
  margin-left: -8px;
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

notebook > header.top > tabs > arrow.up, notebook > header.bottom > tabs > arrow.up {
  margin-right: -8px;
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

notebook > header.left > tabs > arrow {
  border-left-style: none;
}

notebook > header.right > tabs > arrow {
  border-right-style: none;
}

notebook > header.left > tabs > arrow, notebook > header.right > tabs > arrow {
  padding-top: 6px;
  padding-bottom: 6px;
}

notebook > header.left > tabs > arrow.down, notebook > header.right > tabs > arrow.down {
  margin-top: -8px;
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

notebook > header.left > tabs > arrow.up, notebook > header.right > tabs > arrow.up {
  margin-bottom: -8px;
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

notebook > header > tabs > arrow {
  min-height: 16px;
  min-width: 16px;
  border-radius: 0;
}

notebook > header tab {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1), background-size 0, background-image 0;
  min-height: 16px;
  min-width: 16px;
  padding: 6px 6px;
  outline-offset: -6px;
  border-width: 1px;
  border-color: transparent;
  background-image: radial-gradient(circle farthest-corner at center, #4D90D6 10%, transparent 0%);
  background-repeat: no-repeat;
  background-position: center;
  background-size: 0% 0%;
  color: rgba(21, 22, 28, 0.54);
  font-weight: 500;
}

notebook > header tab:hover {
  color: rgba(21, 22, 28, 0.85);
}

notebook > header tab:hover.reorderable-page {
  border-color: rgba(0, 0, 0, 0.12);
  background-color: white;
}

notebook > header tab:disabled {
  color: rgba(21, 22, 28, 0.26);
}

notebook > header tab:checked {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1), background-size 270ms cubic-bezier(0, 0, 0.2, 1), background-image 720ms cubic-bezier(0, 0, 0.2, 1);
  background-image: radial-gradient(circle farthest-corner at center, transparent 10%, transparent 0%);
  background-size: 1000% 1000%;
  color: rgba(21, 22, 28, 0.85);
}

notebook > header tab:checked:disabled {
  color: rgba(21, 22, 28, 0.38);
}

notebook > header tab:checked.reorderable-page {
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #FFFFFF;
}

notebook > header tab button.flat:last-child {
  margin-left: 6px;
  margin-right: -6px;
}

notebook > header tab button.flat:first-child {
  margin-left: -6px;
  margin-right: 6px;
}

notebook > header.top tabs, notebook > header.bottom tabs {
  padding-left: 8px;
  padding-right: 8px;
}

notebook > header.top tabs:not(:only-child):first-child, notebook > header.bottom tabs:not(:only-child):first-child {
  margin-left: 0;
}

notebook > header.top tabs:not(:only-child):last-child, notebook > header.bottom tabs:not(:only-child):last-child {
  margin-right: 0;
}

notebook > header.top tabs tab.reorderable-page, notebook > header.bottom tabs tab.reorderable-page {
  margin: 0 -1px;
  border-style: none solid;
}

notebook > header.left tabs, notebook > header.right tabs {
  padding-top: 8px;
  padding-bottom: 8px;
}

notebook > header.left tabs:not(:only-child):first-child, notebook > header.right tabs:not(:only-child):first-child {
  margin-top: 0;
}

notebook > header.left tabs:not(:only-child):last-child, notebook > header.right tabs:not(:only-child):last-child {
  margin-bottom: 0;
}

notebook > header.left tabs tab.reorderable-page, notebook > header.right tabs tab.reorderable-page {
  margin: -1px 0;
  border-style: solid none;
}

notebook > stack:not(:only-child) {
  background-color: #FFFFFF;
}

/*********
 * Paned *
 *********/
paned > separator {
  min-width: 1px;
  min-height: 1px;
  -gtk-icon-source: none;
  border-style: none;
  background-color: transparent;
  background-image: image(rgba(0, 0, 0, 0.12));
  background-size: 1px 1px;
  background-clip: content-box;
}

paned > separator.wide {
  min-width: 4px;
  min-height: 4px;
  background-color: white;
  background-image: image(rgba(0, 0, 0, 0.12)), image(rgba(0, 0, 0, 0.12));
  background-size: 1px 1px, 1px 1px;
}

paned.horizontal > separator {
  background-repeat: repeat-y;
}

paned.horizontal > separator:dir(ltr) {
  margin: -8px 0 0;
  padding: 0 8px 0 0;
  background-position: left;
}

paned.horizontal > separator:dir(rtl) {
  margin: 0 0 -8px;
  padding: 0 0 0 8px;
  background-position: right;
}

paned.horizontal > separator.wide {
  margin: 0;
  padding: 0;
  background-repeat: repeat-y, repeat-y;
  background-position: left, right;
}

paned.vertical > separator {
  margin: 0 -8px 0;
  padding: 0 0 8px 0;
  background-repeat: repeat-x;
  background-position: top;
}

paned.vertical > separator.wide {
  margin: 0;
  padding: 0;
  background-repeat: repeat-x, repeat-x;
  background-position: bottom, top;
}

/************
 * Pathbars *
 ************/
.caja-pathbar button,
.path-bar button {
  padding-left: 6px;
  padding-right: 6px;
}

.caja-pathbar button label:not(:only-child):first-child,
.path-bar button label:not(:only-child):first-child {
  margin-left: 4px;
}

.caja-pathbar button label:not(:only-child):last-child,
.path-bar button label:not(:only-child):last-child {
  margin-right: 4px;
}

.caja-pathbar button.slider-button,
.path-bar button.slider-button {
  padding-left: 6px;
  padding-right: 6px;
}

:not(headerbar) .caja-pathbar button, .caja-pathbar :not(headerbar) button, :not(headerbar)
.path-bar button {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #4D90D6 0%, transparent 0%) 0 0 0/0 0 0px;
  border-radius: 4px;
}

:not(headerbar) .caja-pathbar button:checked, .caja-pathbar :not(headerbar) button:checked, :not(headerbar)
.path-bar button:checked {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #4D90D6 100%, transparent 0%) 0 0 2/0 0 2px;
}

:not(headerbar) .caja-pathbar button:checked, .caja-pathbar :not(headerbar) button:checked, :not(headerbar) .caja-pathbar button:checked:disabled, .caja-pathbar :not(headerbar) button:checked:disabled, :not(headerbar)
.path-bar button:checked, :not(headerbar)
.path-bar button:checked:disabled {
  background-color: transparent;
}

:not(headerbar) .caja-pathbar button:checked:backdrop, .caja-pathbar :not(headerbar) button:checked:backdrop, :not(headerbar)
.path-bar button:checked:backdrop {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #a8c4e0 100%, transparent 0%) 0 0 2/0 0 2px;
}

/************
 * Popovers *
 ************/
popover.background {
  transition: box-shadow 180ms cubic-bezier(0.4, 0, 0.2, 1);
  padding: 2px;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23);
  background-color: white;
}

popover.background:backdrop {
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
}

popover.background, .csd popover.background {
  border-style: solid;
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.2) rgba(0, 0, 0, 0.3);
  border-radius: 4px;
}

popover.background > stack {
  margin: -4px;
}

popover.background > toolbar {
  margin: -2px;
}

popover.background > list,
popover.background > .view,
popover.background > toolbar {
  border-style: none;
  box-shadow: none;
  background-color: transparent;
}

popover.background.menu button,
popover.background button.model {
  min-height: 32px;
  padding: 0 8px;
  border-radius: 4px;
  outline-offset: 4px;
}

popover.background separator {
  margin: 4px 0;
}

popover.background list separator {
  margin: 0;
}

/*****************
 * Progress bars *
 *****************/
progressbar {
  color: rgba(21, 22, 28, 0.38);
  font-size: smaller;
}

progressbar.horizontal trough,
progressbar.horizontal progress {
  min-height: 4px;
  border-radius: 4px;
}

progressbar.vertical trough,
progressbar.vertical progress {
  min-width: 4px;
  border-radius: 4px;
}

progressbar trough {
  background-color: rgba(77, 144, 214, 0.3);
}

progressbar progress {
  background-color: #4D90D6;
}

progressbar progress:backdrop {
  background-color: #a8c4e0;
  opacity: 0.2;
}

progressbar trough.empty progress {
  all: unset;
}

/************
 * GtkScale *
 ************/
scale {
  padding: 8px;
}

scale trough {
  background-color: rgba(0, 0, 0, 0.26);
  min-width: 4px;
  min-height: 4px;
  border-radius: 9999px;
  outline-color: transparent;
  transition: all 180ms cubic-bezier(0.4, 0, 0.2, 1);
}

scale highlight {
  background-color: #4D90D6;
  border-radius: 9999px;
  transition: all 180ms cubic-bezier(0.4, 0, 0.2, 1);
}

scale fill {
  min-width: 4px;
  min-height: 4px;
  background-color: rgba(77, 144, 214, 0.5);
  border-radius: 9999px;
  transition: all 180ms cubic-bezier(0.4, 0, 0.2, 1);
}

scale slider {
  min-width: 12px;
  min-height: 12px;
  background-color: #4D90D6;
  border-radius: 9999px;
  margin: -8px;
  transition: all 180ms cubic-bezier(0.4, 0, 0.2, 1);
}

scale slider:active {
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23);
}

scale value {
  color: rgba(21, 22, 28, 0.38);
}

scale marks indicator {
  color: rgba(0, 0, 0, 0.26);
  min-width: 6px;
  min-height: 6px;
  margin: -8px;
  padding: 8px;
}

scale marks label {
  color: rgba(21, 22, 28, 0.38);
}

scale:disabled trough {
  background-color: rgba(56, 60, 74, 0.12);
}

scale:disabled slider {
  background-color: white;
  border: 2px solid rgba(21, 22, 28, 0.26);
}

scale:disabled slider:backdrop {
  border: 2px solid rgba(202, 202, 202, 0.482);
  background-color: white;
}

scale:disabled highlight {
  background-color: rgba(21, 22, 28, 0.26);
}

scale:disabled highlight:backdrop {
  background-color: rgba(202, 202, 202, 0.482);
}

scale:backdrop trough {
  background-color: rgba(196, 196, 196, 0.482);
}

scale:backdrop highlight {
  background-color: #a8c4e0;
}

scale:backdrop fill {
  background-color: #a8c4e0;
}

scale:backdrop slider {
  background-color: #a8c4e0;
}

/**************
 * Scrollbars *
 **************/
scrollbar {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1);
  background-color: rgba(255, 255, 255, 0.6);
  background-clip: padding-box;
}

* {
  -GtkScrollbar-has-backward-stepper: false;
  -GtkScrollbar-has-forward-stepper: false;
}

scrollbar.top {
  border-bottom: transparent;
}

scrollbar.bottom {
  border-top: transparent;
}

scrollbar.left {
  border-right: transparent;
}

scrollbar.right {
  border-left: transparent;
}

scrollbar slider {
  transition: all 180ms cubic-bezier(0.4, 0, 0.2, 1), margin 0, border-width 0;
  min-width: 8px;
  min-height: 8px;
  border: 1px solid white;
  border-radius: 9999px;
  background-clip: padding-box;
  background-color: rgba(56, 60, 74, 0.75);
}

scrollbar slider:hover {
  background-color: rgba(21, 22, 28, 0.85);
}

scrollbar slider:active {
  background-color: rgba(21, 22, 28, 0.85);
}

scrollbar slider:disabled {
  background-color: rgba(21, 22, 28, 0.26);
}

scrollbar.fine-tune slider {
  transition: all 180ms cubic-bezier(0.4, 0, 0.2, 1), margin 0, border-width 0, min-width 0, min-height 0;
  min-width: 4px;
  min-height: 4px;
}

scrollbar.fine-tune.horizontal slider {
  margin: 2px 0;
}

scrollbar.fine-tune.vertical slider {
  margin: 0 2px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) {
  border-color: transparent;
  background-color: transparent;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider {
  min-width: 4px;
  min-height: 4px;
  margin: 2px;
  border: 1px solid rgba(255, 255, 255, 0.3);
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) button {
  min-width: 4px;
  min-height: 4px;
  margin: 2px;
  border: 1px solid rgba(255, 255, 255, 0.3);
  border-radius: 9999px;
  background-color: rgba(21, 22, 28, 0.38);
  background-clip: padding-box;
  -gtk-icon-source: none;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) button:disabled {
  background-color: rgba(21, 22, 28, 0.26);
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal slider {
  min-width: 24px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal button {
  min-width: 8px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical slider {
  min-height: 24px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical button {
  min-height: 8px;
}

scrollbar.overlay-indicator.dragging, scrollbar.overlay-indicator.hovering {
  background-color: rgba(255, 255, 255, 0.9);
}

scrollbar.horizontal slider {
  min-width: 24px;
}

scrollbar.vertical slider {
  min-height: 24px;
}

scrollbar button {
  min-width: 16px;
  min-height: 16px;
  padding: 0;
  border-radius: 0;
}

scrollbar.vertical button.down {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

scrollbar.vertical button.up {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

scrollbar.horizontal button.down {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

scrollbar.horizontal button.up {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

/***********
 * Sidebar *
 ***********/
.sidebar {
  border-style: none;
  background-color: white;
}

stacksidebar.sidebar:dir(ltr) list, stacksidebar.sidebar.left list, stacksidebar.sidebar.left:dir(rtl) list, .sidebar:dir(ltr), .sidebar.left, .sidebar.left:dir(rtl) {
  border-right: 1px solid rgba(0, 0, 0, 0.12);
  border-left-style: none;
}

stacksidebar.sidebar:dir(rtl) list, stacksidebar.sidebar.right list, .sidebar:dir(rtl), .sidebar.right {
  border-left: 1px solid rgba(0, 0, 0, 0.12);
  border-right-style: none;
}

.sidebar list {
  background-color: transparent;
}

paned .sidebar.left, paned .sidebar.right, paned .sidebar.left:dir(rtl), paned .sidebar:dir(rtl), paned .sidebar:dir(ltr), paned .sidebar {
  border-style: none;
}

stacksidebar row {
  padding: 6px;
}

stacksidebar row > label {
  padding-left: 6px;
  padding-right: 6px;
}

/**********
 * Switch *
 **********/
switch {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1);
  margin: 6px 0;
  padding: 0 2px;
  border: 6px solid transparent;
  border-radius: 9999px;
  background-color: rgba(0, 0, 0, 0.26);
  background-clip: padding-box;
  font-size: 0;
}

switch:disabled {
  background-color: rgba(56, 60, 74, 0.12);
}

switch:checked {
  background-color: rgba(77, 144, 214, 0.5);
}

switch:checked:disabled, switch:checked:backdrop {
  background-color: rgba(77, 144, 214, 0.3);
}

switch slider {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1);
  min-width: 20px;
  min-height: 20px;
  margin: -3px -2px;
  border-radius: 9999px;
  -gtk-outline-radius: 9999px;
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  background-color: #FFFFFF;
}

switch:hover slider {
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23);
}

switch:checked slider {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1), box-shadow 180ms cubic-bezier(0.4, 0, 0.2, 1), background-image 0, background-color 0.00001s 270ms;
  animation: needs_attention 270ms cubic-bezier(0, 0, 0.2, 1);
  background-color: #4D90D6;
  color: #FFFFFF;
}

switch:backdrop:checked slider {
  background-color: #a8c4e0;
}

switch:disabled slider {
  background-color: white;
}

switch:checked:disabled slider {
  animation: none;
}

/****************
 * File chooser *
 ****************/
placessidebar > viewport.frame {
  border-style: none;
}

placessidebar list {
  padding: 2px 0 6px;
}

placessidebar row {
  min-height: 32px;
  margin: -1px 0;
  padding: 0;
  color: rgba(21, 22, 28, 0.85);
}

placessidebar row > revealer {
  padding: 0 12px;
}

placessidebar row:selected {
  color: #FFFFFF;
  background-color: #4D90D6;
}

placessidebar row:selected:backdrop {
  background-color: #a8c4e0;
}

placessidebar row:disabled {
  color: rgba(21, 22, 28, 0.38);
}

placessidebar row image.sidebar-icon {
  color: rgba(21, 22, 28, 0.85);
}

placessidebar row image.sidebar-icon:dir(ltr) {
  padding-right: 8px;
}

placessidebar row image.sidebar-icon:dir(rtl) {
  padding-left: 8px;
}

placessidebar row:selected image.sidebar-icon {
  color: #FFFFFF;
}

placessidebar row label.sidebar-label:dir(ltr) {
  padding-right: 2px;
}

placessidebar row label.sidebar-label:dir(rtl) {
  padding-left: 2px;
}

placessidebar row.sidebar-placeholder-row {
  min-height: 4px;
  padding: 0 8px;
  background-image: image(#4D90D6);
  background-clip: content-box;
}

placessidebar row.sidebar-new-bookmark-row {
  color: #4D90D6;
}

placessidebar row:drop(active):not(:disabled) {
  box-shadow: inset 0 0 0 2px #4D90D6;
}

placessidebar row:drop(active):not(:disabled):selected {
  background-color: #4D90D6;
  color: #FFFFFF;
}

placesview .server-list-button > image {
  -gtk-icon-transform: rotate(0turn);
}

placesview .server-list-button:checked > image {
  -gtk-icon-transform: rotate(-0.5turn);
}

placesview > actionbar > revealer > box > label {
  padding-left: 8px;
  padding-right: 8px;
}

/************
 * Toolbars *
 ************/
toolbar {
  -GtkWidget-window-dragging: true;
  padding: 2px;
  background-color: white;
}

toolbar:backdrop {
  background-color: white;
}

.osd toolbar {
  background-color: transparent;
}

toolbar.osd, .app-notification, frame.documents-dropdown {
  transition: box-shadow 180ms cubic-bezier(0.4, 0, 0.2, 1);
  padding: 6px;
  border-radius: 4px;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23), inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #FFFFFF;
}

toolbar.osd:backdrop, .app-notification:backdrop, frame.documents-dropdown:backdrop {
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24), inset 0 1px rgba(255, 255, 255, 0.4);
}

toolbar.osd.left, .left.app-notification, frame.left.documents-dropdown, toolbar.osd.right, .right.app-notification, frame.right.documents-dropdown, toolbar.osd.top, .top.app-notification, frame.top.documents-dropdown, toolbar.osd.bottom, .bottom.app-notification, frame.bottom.documents-dropdown {
  border-radius: 0;
}

toolbar.horizontal > separator {
  margin: 2px;
}

toolbar.vertical > separator {
  margin: 2px;
}

toolbar:not(.inline-toolbar):not(.osd) scale,
toolbar:not(.inline-toolbar):not(.osd) spinbutton,
toolbar:not(.inline-toolbar):not(.osd) button {
  margin: 2px;
}

toolbar:not(.inline-toolbar):not(.osd) .linked spinbutton:not(:first-child),
toolbar:not(.inline-toolbar):not(.osd) .linked button:not(:first-child) {
  margin-left: 0;
}

toolbar:not(.inline-toolbar):not(.osd) .linked spinbutton:not(:last-child),
toolbar:not(.inline-toolbar):not(.osd) .linked button:not(:last-child) {
  margin-right: 0;
}

toolbar:not(.inline-toolbar):not(.osd) spinbutton button {
  margin: 0;
}

toolbar:not(.inline-toolbar):not(.osd) switch {
  margin: 8px 2px;
}

.inline-toolbar {
  padding: 6px;
  border-style: solid;
  border-width: 0 1px 1px;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: white;
}

.inline-toolbar:backdrop {
  background-color: white;
}

searchbar,
.location-bar {
  padding: 6px;
  border-style: solid;
  border-width: 0 0 1px;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: white;
  background-clip: border-box;
}

searchbar:backdrop,
.location-bar:backdrop {
  background-color: white;
}

/**************
 * Tree Views *
 **************/
treeview.view {
  border-left-color: rgba(0, 0, 0, 0.26);
  border-top-color: rgba(0, 0, 0, 0.12);
}

* {
  -GtkTreeView-horizontal-separator: 4;
  -GtkTreeView-grid-line-width: 1;
  -GtkTreeView-grid-line-pattern: '';
  -GtkTreeView-tree-line-width: 1;
  -GtkTreeView-tree-line-pattern: '';
  -GtkTreeView-expander-size: 16;
}

treeview.view:selected {
  border-left-color: rgba(255, 255, 255, 0.3);
}

treeview.view:hover, treeview.view:active, treeview.view:selected {
  border-radius: 0;
}

treeview.view.separator {
  min-height: 4px;
  color: rgba(0, 0, 0, 0.12);
}

treeview.view:drop(active) {
  border-style: solid none;
  border-width: 1px;
  border-color: #4D90D6;
}

treeview.view:drop(active).after {
  border-top-style: none;
}

treeview.view:drop(active).before {
  border-bottom-style: none;
}

treeview.view.expander {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  -gtk-icon-transform: rotate(-90deg);
  color: rgba(21, 22, 28, 0.54);
}

treeview.view.expander:dir(rtl) {
  -gtk-icon-transform: rotate(90deg);
}

treeview.view.expander:checked {
  -gtk-icon-transform: unset;
}

treeview.view.expander:hover, treeview.view.expander:active {
  color: rgba(21, 22, 28, 0.85);
}

treeview.view.expander:disabled {
  color: rgba(21, 22, 28, 0.26);
}

treeview.view.expander:selected {
  color: rgba(255, 255, 255, 0.7);
}

treeview.view.expander:selected:hover, treeview.view.expander:selected:active {
  color: #FFFFFF;
}

treeview.view.expander:selected:disabled {
  color: rgba(255, 255, 255, 0.3);
}

treeview.view.progressbar {
  border-bottom: 4px solid #4D90D6;
  box-shadow: none;
  background-color: transparent;
}

treeview.view.progressbar:selected {
  border-bottom-color: #FFFFFF;
}

treeview.view.trough {
  border-bottom: 4px solid rgba(77, 144, 214, 0.3);
  box-shadow: none;
  background-color: transparent;
}

treeview.view.trough:selected {
  border-bottom-color: rgba(255, 255, 255, 0.3);
}

treeview.view header button {
  padding: 2px 6px;
  border-style: none solid solid none;
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.12);
  border-radius: 0;
  background-clip: border-box;
}

treeview.view header button, treeview.view header button:hover, treeview.view header button:active {
  box-shadow: none;
}

treeview.view header button, treeview.view header button:disabled {
  background-color: #FFFFFF;
}

treeview.view header button:last-child {
  border-right-style: none;
}

treeview.view button.dnd,
treeview.view header.button.dnd {
  padding: 2px 6px;
  border-style: none solid solid;
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.12);
  border-radius: 0;
  box-shadow: none;
  background-color: #FFFFFF;
  background-clip: border-box;
  color: #4D90D6;
}

treeview.view acceleditor > label {
  background-color: #4D90D6;
}

/***********
 * Dialogs *
 ***********/
messagedialog.background {
  background-color: white;
}

messagedialog .titlebar {
  min-height: 24px;
  border-style: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: white;
  color: rgba(21, 22, 28, 0.85);
}

messagedialog .titlebar:backdrop {
  background-color: white;
}

messagedialog.csd.background {
  border-bottom-left-radius: 4px;
  border-bottom-right-radius: 4px;
}

messagedialog.csd .dialog-action-area button {
  color: rgba(21, 22, 28, 0.85);
  padding: 8px 16px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
  border-radius: 0;
}

messagedialog.csd .dialog-action-area button:first-child {
  border-bottom-left-radius: 4px;
}

messagedialog.csd .dialog-action-area button:last-child {
  border-bottom-right-radius: 4px;
}

messagedialog.csd .dialog-action-area button:focus {
  background-color: #fc4138;
  color: rgba(21, 22, 28, 0.9);
}

filechooser .dialog-action-box {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

filechooser #pathbarbox {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  background-color: white;
}

filechooserbutton:drop(active) {
  box-shadow: none;
}

/************
 * Ubiquity *
 ************/
#live_installer > #wizard #page_mode #title_section label#page_title {
  color: #f5f6f7;
}

#live_installer > #wizard #progress_eventbox #progress_mode progressbar * {
  border-radius: 9999px;
}

#live_installer > #wizard #progress_eventbox #progress_mode label {
  color: #f5f6f7;
}

/*********
 * Tilix *
 *********/
overlay > revealer.left > scrolledwindow.frame,
overlay > revealer.right > scrolledwindow.frame {
  border-style: none;
  box-shadow: 0 14px 14px rgba(0, 0, 0, 0.25), 0 10px 5px rgba(0, 0, 0, 0.22);
}

overlay > revealer.left > scrolledwindow.frame {
  margin-right: 32px;
}

overlay > revealer.right > scrolledwindow.frame {
  margin-left: 32px;
}

.terminix-session-sidebar,
.tilix-session-sidebar {
  background-image: image(white);
}

button.image-button.session-new-button {
  min-width: 28px;
}

/***********
 * Eclipse *
 ***********/
window.background > box.vertical > scrolledwindow > widget toolbar {
  padding: 2px;
}

window.background > box.vertical > scrolledwindow > widget toolbar separator,
window.background > box.vertical > scrolledwindow > widget toolbar button {
  margin: 2px;
}

window.background > box.vertical > scrolledwindow > widget toolbar button {
  border-radius: 2px;
}

/***********
 * Firefox *
 ***********/
window.background:not(.csd) > widget > separator {
  color: rgba(0, 0, 0, 0.2);
}

window.background:not(.csd) > widget > scrollbar {
  background-clip: border-box;
}

window.background:not(.csd) > widget > scrollbar,
window.background:not(.csd) > widget > frame > border {
  border-color: rgba(0, 0, 0, 0.2);
}

window.background:not(.csd) > widget > entry,
window.background:not(.csd) > widget > button > button {
  border: 1px solid rgba(0, 0, 0, 0.2);
  border-radius: 3px;
  box-shadow: none;
}

window.background:not(.csd) > widget > entry {
  min-height: 30px;
}

window.background:not(.csd) > widget > entry:focus {
  border-color: #4D90D6;
}

window.background:not(.csd) > widget > button > button {
  padding: 4px 8px;
  background-size: auto;
}

window.background:not(.csd) > widget > button > button:hover {
  background-image: image(alpha(currentColor, 0.05));
}

window.background:not(.csd) > widget > button > button:active {
  background-image: image(alpha(currentColor, 0.1));
}

window.background:not(.csd) > window > menu,
window.background:not(.csd) > menu > menu {
  border: none;
}

window.background:not(.csd) > widget > menubar {
  color: rgba(255, 255, 255, 0.6);
}

window.background:not(.csd) > widget > menubar:hover {
  color: #FFFFFF;
}

window.background:not(.csd) > widget > menubar:disabled {
  color: rgba(255, 255, 255, 0.2);
}

window.background:not(.csd) > widget > frame {
  color: rgba(0, 0, 0, 0.2);
}

window.background:not(.csd) > widget > checkbutton > check,
window.background:not(.csd) > widget > radiobutton > radio {
  margin: 0;
  padding: 0;
}

window.background:not(.csd) > window.background > menu > separator {
  color: rgba(0, 0, 0, 0.12);
}

/************
 * Inkscape *
 ************/
#ToolboxCommon > #AuxToolbox #StyleSwatch {
  font-size: smaller;
}

#ToolboxCommon > #AuxToolbox #Kludge {
  padding: 0;
}

#ToolboxCommon > #AuxToolbox spinbutton,
#ToolboxCommon > #AuxToolbox entry {
  min-height: 32px;
}

#ToolboxCommon > #AuxToolbox button:not(.up):not(.down) {
  min-height: 24px;
  min-width: 16px;
  padding: 4px 8px;
  border-radius: 2px;
  -gtk-outline-radius: 2px;
}

#ToolboxCommon > #AuxToolbox spinbutton button {
  border-width: 4px;
}

#ToolboxCommon > toolbar.vertical {
  margin-top: -4px;
}

#ToolboxCommon > toolbar.vertical button {
  min-height: 24px;
  min-width: 24px;
  padding: 4px;
  border-radius: 2px;
  -gtk-outline-radius: 2px;
}

#CanvasTable button {
  min-height: 16px;
  min-width: 16px;
  padding: 0;
}

#CanvasTable #HorizontalScrollbar {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

#CanvasTable #VerticalScrollbar:dir(ltr) {
  border-left: 1px solid rgba(0, 0, 0, 0.12);
}

#CanvasTable #VerticalScrollbar:dir(rtl) {
  border-right: 1px solid rgba(0, 0, 0, 0.12);
}

#Canvas_and_Dock frame > border {
  border: none;
}

#Canvas_and_Dock widget > widget > button.flat {
  min-height: 16px;
  min-width: 16px;
  padding: 4px;
}

#Canvas_and_Dock widget > widget > box.horizontal image {
  padding: 4px;
}

#Canvas_and_Dock box.horizontal > box.vertical > button.flat {
  min-height: 16px;
  min-width: 24px;
  padding: 8px 4px;
}

/***********
 * Synapse *
 ***********/
box.vertical > widget > widget:selected {
  background-color: #4D90D6;
}

/****************
 * Libre-Office *
 ****************/
window.background:not(.solid-csd) > notebook:not(.frame) {
  border: 0 none transparent;
  background-color: white;
}

window.background:not(.solid-csd) > notebook:not(.frame) > stack {
  border: none;
  background-color: white;
  box-shadow: none;
}

window.background:not(.solid-csd) > notebook:not(.frame) > header.top {
  border: 0 none transparent;
  background-color: white;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23);
}

window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs, window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs > tab {
  background-color: transparent;
}

window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs,
window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs label,
window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs image, window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs > tab,
window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs > tab label,
window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs > tab image {
  color: rgba(21, 22, 28, 0.54);
}

window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs:hover,
window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs:hover label,
window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs:hover image, window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs:checked,
window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs:checked label,
window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs:checked image, window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs > tab:hover,
window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs > tab:hover label,
window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs > tab:hover image, window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs > tab:checked,
window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs > tab:checked label,
window.background:not(.solid-csd) > notebook:not(.frame) > header.top tabs > tab:checked image {
  color: rgba(21, 22, 28, 0.85);
}

/*********************
 * Chrome / Chromium *
 *********************/
tooltip.chromium {
  background-color: #FFFFFF;
}

window.background.chromium {
  background-color: white;
  color: rgba(21, 22, 28, 0.54);
}

window.background.chromium button {
  border-width: 1px;
  border-style: solid;
  border-color: rgba(56, 60, 74, 0.3);
}

window.background.chromium *:backdrop button {
  border-color: transparent;
}

window.background.chromium entry.chromium, window.background.chromium entry.chromium:focus {
  border-image: none;
  border: 1px solid rgba(56, 60, 74, 0.3);
}

window.background.chromium > textview.view {
  background-color: rgba(255, 255, 255, 0.5);
}

window.background.chromium > textview.view text {
  color: rgba(21, 22, 28, 0.54);
  caret-color: rgba(21, 22, 28, 0.54);
}

window.background.chromium > textview.view text:focus {
  color: rgba(21, 22, 28, 0.85);
  caret-color: rgba(21, 22, 28, 0.85);
}

window.background.chromium > spinner {
  color: rgba(56, 60, 74, 0.85);
}

window.background.chromium > spinner:disabled {
  color: rgba(207, 208, 211, 0.955);
}

window.background.chromium menu menuitem {
  color: rgba(21, 22, 28, 0.85);
}

window.background.chromium menu menuitem:hover {
  background-color: rgba(237, 237, 238, 0.985);
}

window.background.chromium menu menuitem:disabled {
  color: rgba(21, 22, 28, 0.38);
}

/*********
 * Unity *
 *********/
UnityDecoration {
  -UnityDecoration-extents: 28px 0 0 0;
  -UnityDecoration-input-extents: 8px;
  -UnityDecoration-shadow-offset-x: 0;
  -UnityDecoration-shadow-offset-y: 3px;
  -UnityDecoration-active-shadow-color: rgba(0, 0, 0, 0.48);
  -UnityDecoration-active-shadow-radius: 18px;
  -UnityDecoration-inactive-shadow-color: rgba(0, 0, 0, 0.32);
  -UnityDecoration-inactive-shadow-radius: 6px;
  -UnityDecoration-glow-size: 8px;
  -UnityDecoration-glow-color: #4D90D6;
  -UnityDecoration-title-indent: 4px;
  -UnityDecoration-title-fade: 32px;
  -UnityDecoration-title-alignment: 0.0;
}

UnityDecoration .top {
  padding: 0 2px;
  border-style: none;
  border-radius: 2px 2px 0 0;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  background-color: #15161c;
  color: #FFFFFF;
}

UnityDecoration .top:backdrop {
  color: rgba(255, 255, 255, 0.6);
}

UnityDecoration .menuitem {
  color: rgba(255, 255, 255, 0.6);
}

UnityDecoration .menuitem:hover {
  box-shadow: inset 0 -2px #4D90D6;
  background-color: transparent;
  color: #FFFFFF;
}

.background:not(.csd) headerbar:not(.titlebar) {
  border-radius: 0;
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
}

.background:not(.csd) headerbar:not(.titlebar).inline-toolbar {
  border-style: none;
}

UnityPanelWidget,
.unity-panel {
  background-color: black;
  color: #FFFFFF;
}

UnityPanelWidget:backdrop,
.unity-panel:backdrop {
  color: rgba(255, 255, 255, 0.6);
}

.unity-panel.menuitem,
.unity-panel .menuitem {
  color: rgba(255, 255, 255, 0.6);
}

.unity-panel.menubar.menuitem:hover,
.unity-panel.menubar .menuitem *:hover {
  box-shadow: inset 0 -2px #4D90D6;
  background-color: transparent;
  color: #FFFFFF;
}

.menu IdoPlaybackMenuItem.menuitem:active {
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
  animation: spin 1s linear infinite;
  color: #4D90D6;
}

/**************
 * Mate-Panel *
 **************/
.mate-panel-menu-bar menubar,
#PanelApplet-window-menu-applet-button {
  background-color: transparent;
}

#PanelPlug,
PanelToplevel.background {
  background-color: black;
  color: #FFFFFF;
  font-weight: 500;
}

PanelToplevel > grid > button, .mate-panel-menu-bar #PanelApplet button {
  color: rgba(255, 255, 255, 0.6);
}

PanelToplevel > grid > button:hover, .mate-panel-menu-bar #PanelApplet button:hover, PanelToplevel > grid > button:active, .mate-panel-menu-bar #PanelApplet button:active {
  color: #FFFFFF;
}

PanelToplevel > grid > button:disabled, .mate-panel-menu-bar #PanelApplet button:disabled {
  color: rgba(255, 255, 255, 0.2);
}

PanelToplevel > grid > button:checked, .mate-panel-menu-bar #PanelApplet button:checked {
  background-color: rgba(255, 255, 255, 0.3);
  color: #FFFFFF;
}

PanelToplevel > grid > button:checked:disabled, .mate-panel-menu-bar #PanelApplet button:checked:disabled {
  background-color: rgba(255, 255, 255, 0.12);
  color: rgba(255, 255, 255, 0.3);
}

PanelToplevel > grid > button {
  padding: 0 4px;
  border-radius: 0;
}

PanelWidget button, PanelWidget button:hover, PanelWidget button:active {
  color: rgba(255, 255, 255, 0.6);
}

PanelSeparator {
  color: rgba(255, 255, 255, 0.12);
}

MatePanelAppletFrameDBus {
  border-style: solid;
  border-width: 0 1px;
  border-color: rgba(255, 255, 255, 0.12);
}

.mate-panel-menu-bar menubar menuitem {
  padding: 4px;
}

.mate-panel-menu-bar menubar menu menuitem {
  padding: 6px;
}

.mate-panel-menu-bar #PanelApplet button {
  -GtkWidget-window-dragging: true;
  padding: 4px;
  border-radius: 0;
}

PanelApplet.wnck-applet .wnck-pager {
  background-color: transparent;
  color: #4D90D6;
}

PanelApplet.wnck-applet .wnck-pager:hover {
  background-color: rgba(255, 255, 255, 0.12);
}

PanelApplet.wnck-applet .wnck-pager:active {
  background-color: rgba(255, 255, 255, 0.3);
}

PanelApplet.wnck-applet .wnck-pager:selected {
  background-color: #4D90D6;
}

#MatePanelPocilloupWindow {
  border: 1px solid rgba(0, 0, 0, 0.12);
  border-radius: 5px;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
}

#MatePanelPocilloupWindow frame > border {
  border-style: none;
}

#MatePanelPocilloupWindow ClockMap {
  border: 1px solid rgba(0, 0, 0, 0.12);
}

na-tray-applet {
  -NaTrayApplet-icon-padding: 3px;
  -NaTrayApplet-icon-size: 16;
}

.mate-panel-menu-bar {
  -PanelMenuBar-icon-visible: true;
}

.mate-panel-applet-slider {
  background-color: transparent;
}

.mate-panel-applet-slider frame {
  border: 1px solid rgba(0, 0, 0, 0.12);
  border-radius: 5px;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: white;
}

.mate-panel-applet-slider frame frame {
  all: unset;
}

.mate-panel-applet-slider frame > border {
  border-style: none;
}

/*********************
 * CAJA File manager *
 *********************/
.caja-navigation-window button.toggle.image-button {
  border-radius: 4px;
}

.caja-pathbar button {
  margin: 0 -1px 0 -2px;
}

.caja-pathbar button > widget {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  -GtkArrow-arrow-scaling: 1;
}

.caja-side-pane notebook viewport.frame,
.caja-side-pane notebook widget .vertical {
  background-color: #FFFFFF;
}

.caja-side-pane notebook,
.caja-notebook {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.caja-side-pane notebook .frame,
.caja-notebook .frame {
  border-style: none;
}

.caja-navigation-window statusbar {
  margin: 0 -10px;
  padding: 0 4px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.caja-notebook frame > border {
  border-style: none;
}

#caja-extra-view-widget {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  background-color: white;
}

#caja-extra-view-widget > box > box > label {
  font-weight: bold;
}

/*********
 * Pluma *
 *********/
.pluma-window statusbar {
  margin: 0 -10px;
  padding: 0 4px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.pluma-window statusbar frame > border {
  border-style: none;
}

.pluma-window statusbar frame button.flat {
  padding: 0 4px;
  border-radius: 0;
}

.pluma-window statusbar frame button.flat widget {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  -GtkArrow-arrow-scaling: 1;
}

.pluma-print-preview toolbar {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

.pluma-window paned.horizontal box.vertical box.horizontal button.flat {
  margin: 1px;
}

.pluma-window paned.horizontal box.vertical .frame {
  border-style: none;
}

.pluma-window paned.horizontal box.vertical notebook.frame {
  margin-top: -1px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.pluma-window paned.horizontal box.vertical notebook.frame box.vertical toolbar.horizontal {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

/*********
 * Atril *
 *********/
.atril-window paned.horizontal box.vertical .frame {
  border-style: none;
}

.atril-window paned.horizontal box.vertical notebook .frame {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

/* mate-screensaver lock dialog */
.lock-dialog {
  box-shadow: 0 14px 14px rgba(0, 0, 0, 0.25), 0 10px 5px rgba(0, 0, 0, 0.22), inset 0 1px rgba(56, 60, 74, 0.85);
  background-color: rgba(56, 60, 74, 0.85);
  color: #FFFFFF;
  /*& button {
        @extend %selected-button;
  }*/
}

.lock-dialog frame > border {
  border-style: none;
}

.lock-dialog entry, .lock-dialog entry:focus textview text {
  background-color: transparent;
  color: #FFFFFF;
  border-style: none;
  border-bottom: 1px solid rgba(56, 60, 74, 0.85);
  box-shadow: none;
}

.lock-dialog notebook {
  color: #FFFFFF;
}

/******************
 * Budgie Desktop *
 ******************/
.budgie-container {
  background-color: transparent;
}

.budgie-menu.background {
  padding: 0;
  background-color: #FFFFFF;
}

.budgie-menu scrolledwindow,
.budgie-menu list,
.budgie-menu row,
.budgie-menu scrollbar {
  min-width: 0;
  min-height: 0;
  border: none;
  background: none;
  box-shadow: none;
}

.budgie-menu scrollbar,
.budgie-menu entry.search {
  background-color: transparent;
}

.budgie-menu entry.search {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  border-radius: 0;
  box-shadow: none;
  font-size: 120%;
}

.budgie-menu .categories:dir(ltr) {
  border-bottom-left-radius: 4px;
}

.budgie-menu .categories:dir(rtl) {
  border-bottom-right-radius: 4px;
}

.budgie-menu button {
  min-height: 32px;
  padding: 0 8px;
  border-radius: 0;
  color: rgba(21, 22, 28, 0.85);
  font-weight: normal;
}

.budgie-menu button:disabled {
  color: rgba(21, 22, 28, 0.38);
}

.budgie-menu button:checked:disabled {
  background-color: #4D90D6;
}

.budgie-menu row {
  padding: 0;
}

.budgie-menu row:hover {
  box-shadow: none;
}

button.budgie-menu-launcher {
  padding: 0 2px;
  color: #FFFFFF;
}

.budgie-popover {
  border-style: none;
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.12);
  border-radius: 1px;
  box-shadow: 0 3px 4px rgba(0, 0, 0, 0.28);
  background-color: white;
}

.budgie-popover .container {
  padding: 2px;
}

.budgie-popover border {
  border: none;
}

popover.background.user-menu {
  padding: 8px;
}

popover.background.user-menu .content-box {
  background-color: transparent;
}

popover.background.user-menu separator {
  margin: 4px 0;
}

popover.background.user-menu row {
  padding: 0;
  box-shadow: none;
  background-image: none;
}

button.raven-trigger {
  padding: 0 4px;
  color: #FFFFFF;
}

popover.background.places-menu {
  padding: 8px;
}

popover.background.places-menu .name-button.text-button {
  padding-left: 8px;
  padding-right: 8px;
}

popover.background.places-menu .name-button.text-button image:dir(ltr) {
  margin-right: 3px;
}

popover.background.places-menu .name-button.text-button image:dir(rtl) {
  margin-left: 3px;
}

popover.background.places-menu .places-section-header > image:dir(ltr) {
  margin: 0 -2px 0 5px;
}

popover.background.places-menu .places-section-header > image:dir(rtl) {
  margin: 0 5px 0 -2px;
}

popover.background.places-menu .places-list {
  margin-top: 4px;
  padding-top: 4px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
  background-color: transparent;
}

popover.background.places-menu row {
  padding: 0;
  box-shadow: none;
  background-image: none;
}

.budgie-panel {
  background-color: #383c4a;
  color: #FFFFFF;
  font-weight: 500;
}

.budgie-panel button {
  border-radius: 0;
  color: #FFFFFF;
}

.budgie-panel .horizontal.titlebar {
  background-color: transparent;
  border: none;
  min-height: 0px;
  color: #FFFFFF;
  box-shadow: none;
}

.budgie-panel .horizontal.titlebar .image-button.titlebutton.close {
  background-color: transparent;
}

.budgie-panel.transparent {
  background-color: rgba(0, 0, 0, 0.3);
}

.budgie-panel separator {
  background-color: rgba(255, 255, 255, 0.3);
}

.budgie-panel .alert {
  color: #4D90D6;
}

.budgie-panel .end-region {
  background-color: rgba(0, 0, 0, 0.3);
  border-radius: 0px;
}

.budgie-panel .end-region label {
  font-weight: 700;
}

.budgie-panel #tasklist-button {
  padding: 0 4px;
}

.budgie-panel #tasklist-button:checked {
  background-color: rgba(255, 255, 255, 0.12);
}

.budgie-panel button.flat.launcher {
  padding: 0;
}

.budgie-panel button.flat.launcher:checked {
  background-color: rgba(255, 255, 255, 0.12);
}

.budgie-panel button.flat.launcher:not(:checked) {
  color: rgba(255, 255, 255, 0.5);
}

.budgie-panel button.flat.launcher:not(:checked):hover, .budgie-panel button.flat.launcher:not(:checked):active {
  color: rgba(255, 255, 255, 0.7);
}

.budgie-panel button.flat.launcher:not(:checked):disabled {
  color: rgba(255, 255, 255, 0.3);
}

.top .shadow-block {
  background-color: transparent;
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.23), rgba(0, 0, 0, 0.08), transparent);
}

.bottom .shadow-block {
  background-color: transparent;
  background-image: linear-gradient(to top, rgba(0, 0, 0, 0.23), rgba(0, 0, 0, 0.08), transparent);
}

.left .shadow-block {
  background-color: transparent;
  background-image: linear-gradient(to right, rgba(0, 0, 0, 0.23), rgba(0, 0, 0, 0.08), transparent);
}

.right .shadow-block {
  background-color: transparent;
  background-image: linear-gradient(to left, rgba(0, 0, 0, 0.23), rgba(0, 0, 0, 0.08), transparent);
}

.top .budgie-panel #tasklist-button, .budgie-panel .top #tasklist-button, .top .budgie-panel button.flat.launcher, .budgie-panel .top button.flat.launcher {
  border-image: radial-gradient(circle closest-corner at center calc(1px), currentColor 0%, transparent 0%) 0 0 0 0/0 0 0 0;
}

.top .budgie-panel #tasklist-button:checked, .budgie-panel .top #tasklist-button:checked, .top .budgie-panel button.flat.launcher:checked, .budgie-panel .top button.flat.launcher:checked, .top .budgie-panel .unpinned button.flat.launcher, .budgie-panel .unpinned .top button.flat.launcher, .top
.budgie-panel .pinned button.flat.launcher.running,
.budgie-panel .pinned .top button.flat.launcher.running {
  border-image: radial-gradient(circle closest-corner at center calc(1px), currentColor 100%, transparent 0%) 2 0 0 0/2px 0 0 0;
}

.bottom .budgie-panel #tasklist-button, .budgie-panel .bottom #tasklist-button, .bottom .budgie-panel button.flat.launcher, .budgie-panel .bottom button.flat.launcher {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), currentColor 0%, transparent 0%) 0 0 0 0/0 0 0 0;
}

.bottom .budgie-panel #tasklist-button:checked, .budgie-panel .bottom #tasklist-button:checked, .bottom .budgie-panel button.flat.launcher:checked, .budgie-panel .bottom button.flat.launcher:checked, .bottom .budgie-panel .unpinned button.flat.launcher, .budgie-panel .unpinned .bottom button.flat.launcher, .bottom
.budgie-panel .pinned button.flat.launcher.running,
.budgie-panel .pinned .bottom button.flat.launcher.running {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), currentColor 100%, transparent 0%) 0 0 2 0/0 0 2px 0;
}

.left .budgie-panel #tasklist-button, .budgie-panel .left #tasklist-button, .left .budgie-panel button.flat.launcher, .budgie-panel .left button.flat.launcher {
  border-image: radial-gradient(circle closest-corner at calc(1px) center, currentColor 0%, transparent 0%) 0 0 0 0/0 0 0 0;
}

.left .budgie-panel #tasklist-button:checked, .budgie-panel .left #tasklist-button:checked, .left .budgie-panel button.flat.launcher:checked, .budgie-panel .left button.flat.launcher:checked, .left .budgie-panel .unpinned button.flat.launcher, .budgie-panel .unpinned .left button.flat.launcher, .left
.budgie-panel .pinned button.flat.launcher.running,
.budgie-panel .pinned .left button.flat.launcher.running {
  border-image: radial-gradient(circle closest-corner at calc(1px) center, currentColor 100%, transparent 0%) 0 2 0 0/0 2px 0 0;
}

.right .budgie-panel #tasklist-button, .budgie-panel .right #tasklist-button, .right .budgie-panel button.flat.launcher, .budgie-panel .right button.flat.launcher {
  border-image: radial-gradient(circle closest-corner at calc(100% - 1px) center, currentColor 0%, transparent 0%) 0 0 0 0/0 0 0 0;
}

.right .budgie-panel #tasklist-button:checked, .budgie-panel .right #tasklist-button:checked, .right .budgie-panel button.flat.launcher:checked, .budgie-panel .right button.flat.launcher:checked, .right .budgie-panel .unpinned button.flat.launcher, .budgie-panel .unpinned .right button.flat.launcher, .right
.budgie-panel .pinned button.flat.launcher.running,
.budgie-panel .pinned .right button.flat.launcher.running {
  border-image: radial-gradient(circle closest-corner at calc(100% - 1px) center, currentColor 100%, transparent 0%) 0 0 0 2/0 0 0 2px;
}

frame.raven-frame > border {
  border-style: none;
  box-shadow: 0 14px 14px rgba(0, 0, 0, 0.25), 0 10px 5px rgba(0, 0, 0, 0.22);
}

.top frame.raven-frame > border {
  margin-bottom: 2px;
}

.bottom frame.raven-frame > border {
  margin-top: 2px;
}

.left frame.raven-frame > border {
  margin-right: 2px;
}

.right frame.raven-frame > border {
  margin-left: 2px;
}

.raven {
  background-color: white;
}

.raven > stack {
  margin-bottom: -10px;
}

.raven stackswitcher.linked > button {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #c450d8 0%, transparent 0%) 0 0 0/0 0 0px;
  border-radius: 0;
}

.raven stackswitcher.linked > button:checked {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #c450d8 100%, transparent 0%) 0 0 2/0 0 2px;
  background-color: transparent;
}

.raven .raven-header {
  min-height: 32px;
  padding: 2px;
}

.raven .raven-header:not(.top) {
  margin-top: -6px;
}

.raven .raven-header.top {
  padding: 2px 0;
  background-color: #4D90D6;
  color: #FFFFFF;
}

.raven .raven-header.top stackswitcher button {
  margin: -6px 0;
  min-height: 32px;
}

.raven .raven-header.top button.image-button:dir(ltr) {
  margin-right: 2px;
}

.raven .raven-header.top button.image-button:dir(rtl) {
  margin-left: 2px;
}

.raven .raven-header.top > image {
  margin: 0 8px;
}

.raven .raven-header.top > label {
  margin: -8px;
  font-weight: bold;
}

.raven .raven-header.bottom {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.raven viewport.frame .raven-header {
  margin-top: -8px;
}

.raven .raven-background {
  border-style: solid none;
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #FFFFFF;
}

.raven .raven-background.frame {
  border-style: solid none;
}

.raven .raven-background > overlay > widget > image {
  color: rgba(56, 60, 74, 0.12);
}

.raven .raven-background grid > label:first-child {
  min-height: 32px;
}

.raven scrolledwindow.raven-background {
  border-bottom-style: none;
}

.raven .raven-header.top + .raven-background {
  border-style: none;
  background-color: #4D90D6;
  color: #FFFFFF;
}

.raven .raven-header.top + .raven-background stackswitcher button {
  margin: -6px 0;
}

.raven .powerstrip button {
  margin: 2px 0 1px;
  padding: 12px;
}

.raven .option-subtitle {
  font-size: smaller;
}

calendar.raven-calendar {
  border-style: none;
  background-color: transparent;
}

calendar.raven-calendar:selected {
  border-radius: 4px;
  background-color: #4D90D6;
}

.raven-mpris {
  background-color: rgba(0, 0, 0, 0.6);
  color: #FFFFFF;
}

.raven-mpris label {
  min-height: 24px;
}

.raven-mpris button.image-button {
  padding: 12px;
}

.budgie-notification-window, .budgie-osd-window, .budgie-switcher-window {
  background-color: transparent;
  border-radius: 2px;
  color: #FFFFFF;
}

.budgie-notification-window button, .budgie-osd-window button, .budgie-switcher-window button {
  color: #FFFFFF;
}

.budgie-notification-window > box, .budgie-osd-window > box, .budgie-switcher-window > box {
  background-color: #383c4a;
  color: #FFFFFF;
  box-shadow: 0 3px 4px rgba(0, 0, 0, 0.28);
}

.budgie-notification-window > box > grid, .budgie-osd-window > box > grid, .budgie-switcher-window > box > grid {
  background-color: #383c4a;
  color: #FFFFFF;
}

.budgie-notification .notification-title, .budgie-switcher .notification-title {
  font-size: 120%;
}

.budgie-osd .budgie-osd-text {
  font-size: 120%;
}

.drop-shadow {
  margin: 5px 9px;
  padding: 3px;
  border-radius: 2px;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23), inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: white;
}

.drop-shadow .linked > button {
  border-radius: 2px;
}

.budgie-session-dialog, .budgie-polkit-dialog, .budgie-run-dialog {
  border-radius: 2px;
  background-color: white;
}

.budgie-session-dialog decoration, .budgie-polkit-dialog decoration, .budgie-run-dialog decoration {
  border-radius: 2px;
}

.budgie-session-dialog label:not(:last-child),
.budgie-session-dialog .dialog-title {
  font-size: 120%;
}

.budgie-session-dialog .linked.horizontal > button {
  padding: 8px 16px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
  border-radius: 0;
}

.budgie-session-dialog .linked.horizontal > button:first-child {
  border-bottom-left-radius: 2px;
}

.budgie-session-dialog .linked.horizontal > button:last-child {
  border-bottom-right-radius: 2px;
}

.budgie-polkit-dialog .message {
  color: rgba(21, 22, 28, 0.38);
}

.budgie-polkit-dialog .failure {
  color: #f80f04;
}

.budgie-run-dialog {
  background-color: #FFFFFF;
}

.budgie-run-dialog entry.search {
  font-size: 120%;
  padding: 6px 14px;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: transparent;
}

.budgie-run-dialog list .dim-label, .budgie-run-dialog list label.separator, .budgie-run-dialog list .titlebar:not(headerbar) .subtitle, .titlebar:not(headerbar) .budgie-run-dialog list .subtitle, .budgie-run-dialog list
headerbar .subtitle,
headerbar .budgie-run-dialog list .subtitle, .budgie-run-dialog list .budgie-notification .notification-body, .budgie-notification .budgie-run-dialog list .notification-body, .budgie-run-dialog list .budgie-switcher .notification-body, .budgie-switcher .budgie-run-dialog list .notification-body {
  opacity: 1;
}

.budgie-run-dialog scrolledwindow {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

widget > box.workspace-switcher > box.workspace-layout widget.workspace-item {
  background-image: image(rgba(255, 255, 255, 0.4));
  background-repeat: no-repeat;
  transition-duration: 0s;
}

widget > box.workspace-switcher > box.workspace-layout widget.workspace-item.current-workspace {
  background-image: image(rgba(21, 22, 28, 0.54));
}

.top widget > box.workspace-switcher > box.workspace-layout widget.workspace-item {
  background-position: top center;
  background-size: calc(100% - 4px) 2px;
}

.bottom widget > box.workspace-switcher > box.workspace-layout widget.workspace-item {
  background-position: bottom center;
  background-size: calc(100% - 4px) 2px;
}

.left widget > box.workspace-switcher > box.workspace-layout widget.workspace-item {
  background-position: left center;
  background-size: 2px calc(100% - 4px);
}

.right widget > box.workspace-switcher > box.workspace-layout widget.workspace-item {
  background-position: right center;
  background-size: 2px calc(100% - 4px);
}

widget > box.workspace-switcher > box.workspace-layout widget.workspace-item button.workspace-icon-button {
  min-width: 24px;
  min-height: 24px;
  padding: 4px;
  border-radius: 2px;
}

widget > box.workspace-switcher > box.workspace-layout widget.workspace-item button.workspace-icon-button > image {
  opacity: 0.54;
}

widget > box.workspace-switcher > box.workspace-layout widget.workspace-item button.workspace-icon-button:hover, widget > box.workspace-switcher > box.workspace-layout widget.workspace-item button.workspace-icon-button:active {
  -gtk-icon-effect: highlight;
}

widget > box.workspace-switcher > box.workspace-layout widget.workspace-item button.workspace-icon-button:hover > image, widget > box.workspace-switcher > box.workspace-layout widget.workspace-item button.workspace-icon-button:active > image {
  opacity: 0.87;
}

widget > box.workspace-switcher > box.workspace-layout widget.workspace-item label.workspace-more-label {
  font-weight: 700;
  opacity: 0.54;
}

widget > box.workspace-switcher > box.workspace-layout widget.workspace-item.current-workspace button.workspace-icon-button > image {
  opacity: 1.0;
}

widget > box.workspace-switcher > box.workspace-layout widget.workspace-item.current-workspace button.workspace-icon-button:hover, widget > box.workspace-switcher > box.workspace-layout widget.workspace-item.current-workspace button.workspace-icon-button:active {
  -gtk-icon-effect: highlight;
}

widget > box.workspace-switcher > box.workspace-layout widget.workspace-item.current-workspace label.workspace-more-label {
  opacity: 1.0;
}

widget > box.workspace-switcher button.image-button.workspace-add-button {
  min-width: 24px;
  min-height: 24px;
  padding: 4px;
  border-radius: 0;
  color: #FFFFFF;
  background-color: transparent;
}

widget > box.workspace-switcher button.image-button.workspace-add-button:hover {
  background-color: transparent;
  color: #FFFFFF;
}

widget > box.workspace-switcher button.image-button.workspace-add-button:active {
  background-color: transparent;
  color: #FFFFFF;
}

/************
 * Terminal *
 ************/
terminal-window > headerbar.titlebar > box.right > .close {
  margin-right: -2px;
  margin-left: -2px;
}

terminal-window > box {
  border: 2px solid #383c4a;
}

terminal-window > box:backdrop {
  border: 2px solid #444856;
}

/******************
 * Control center *
 *****************/
window.csd > box.horizontal box.vertical > scrolledwindow.view > viewport.frame > stack > list > row:selected {
  background-color: #4D90D6;
  color: #FFFFFF;
}

window.csd > box.horizontal box.vertical > scrolledwindow.view > viewport.frame > stack > list > row:selected:backdrop {
  background-color: #a8c4e0;
}

window.csd > box.horizontal widget > overlay > box.vertical > grid.horizontal > stack > button.toggle {
  margin: 6px;
}

/****************
 * Eye of GNOME *
 ****************/
window > box > box > box > paned > overlay > grid > overlay > revealer > button {
  margin: 6px;
}

window > box > box > box > paned > overlay > grid > overlay > revealer > box.linked {
  padding: 6px;
}

window.csd > headerbar.titlebar > box.linked > button.image-button {
  border-image: none;
}

/**********
 * Evince *
 **********/
window.csd > headerbar.toolbar > toolitem > box.raised > entry {
  min-width: 24px;
}

window.csd > headerbar.toolbar > toolitem > box.raised > entry:first-child {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

window.csd > headerbar.toolbar > toolitem > box.raised > entry:first-child:focus {
  border-bottom-left-radius: 0;
}

window.csd > headerbar.toolbar > toolitem > box.raised > entry:nth-child(2) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

window.csd > headerbar.toolbar > toolitem > box.raised > entry:nth-child(2):focus {
  border-bottom-right-radius: 0;
}

/************
 * Nautilus *
 ************/
.nautilus-window row:selected {
  background-color: #4D90D6;
}

.nautilus-window row:selected:backdrop {
  background-color: #a8c4e0;
}

.nautilus-window,
.nautilus-window notebook,
.nautilus-window notebook > stack {
  background-color: #FFFFFF;
}

.nautilus-desktop.nautilus-canvas-item:not(:selected), .caja-desktop.caja-canvas-item:not(:selected) {
  color: #FFFFFF;
  text-shadow: 0 1px 1px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
}

@keyframes needs_attention_keyframes {
  to {
    background-color: alpha(currentColor, 0.3);
  }
}

.nautilus-operations-button-needs-attention {
  animation: needs_attention_keyframes 270ms cubic-bezier(0.4, 0, 0.2, 1) 2 alternate;
}

.nautilus-operations-button-needs-attention-multiple {
  animation: needs_attention_keyframes 270ms cubic-bezier(0.4, 0, 0.2, 1) 4 alternate;
}

.nautilus-window .floating-bar {
  min-height: 32px;
  padding: 0;
  border-style: solid solid none;
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.12);
  border-radius: 3px 3px 0 0;
  background-color: #FFFFFF;
  background-clip: padding-box;
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1), border-width 0;
}

.nautilus-window .floating-bar.bottom.left {
  margin-right: 7px;
  border-left-style: none;
  border-top-left-radius: 0;
}

.nautilus-window .floating-bar.bottom.right {
  margin-left: 7px;
  border-right-style: none;
  border-top-right-radius: 0;
}

.nautilus-window .floating-bar button {
  margin: 6px;
}

.disk-space-display.unknown {
  background-color: #e0a100;
}

.disk-space-display.used {
  background-color: #4D90D6;
}

.disk-space-display.free {
  background-color: rgba(56, 60, 74, 0.12);
}

.nautilus-window searchbar {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.nautilus-window .searchbar-container {
  margin-top: -1px;
}

.conflict-row:not(:selected) {
  background-color: #f6e3b3;
}

.nautilus-window flowboxchild > widget > .icon-item-background {
  padding: 4px;
  border-radius: 4px;
}

.nautilus-window flowboxchild:selected {
  background-color: transparent;
}

.nautilus-window flowboxchild:selected > widget > .icon-item-background {
  background-color: #4D90D6;
}

dialog.background > box.dialog-vbox.vertical > grid.horizontal > scrolledwindow.frame {
  border-style: none;
}

dialog.background > box.dialog-vbox.vertical > grid.horizontal > box.horizontal:last-child {
  margin: -6px 0 0 -6px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

dialog.background > box.dialog-vbox.vertical > grid.horizontal > box.horizontal:last-child > label {
  margin: 0 8px;
}

dialog.background > box.dialog-vbox.vertical > grid.horizontal > box.horizontal:last-child > box > button {
  border-radius: 0;
}

.nautilus-window > popover.menu:not(:last-child) {
  padding: 3px;
}

.nautilus-window > popover.menu:not(:last-child) > stack > box > box > box {
  margin-top: -6px;
}

.nautilus-window > popover.menu:not(:last-child) > stack > box > box > box > box {
  margin-bottom: -6px;
}

.nautilus-window > popover.menu:not(:last-child) > stack > box > box > box > box.linked {
  margin-top: 1px;
}

.nautilus-window > popover.menu:not(:last-child) separator {
  margin-bottom: -2px;
}

.nautilus-menu-sort-heading {
  margin: 1px 3px;
  font-weight: 500;
}

.nautilus-menu-sort-heading:disabled {
  color: rgba(21, 22, 28, 0.38);
}

.nautilus-window paned > separator {
  background-color: white;
}

/*********
 * gedit *
 *********/
.open-document-selector-path-label {
  color: rgba(21, 22, 28, 0.54);
  font-size: smaller;
}

.open-document-selector-path-label:selected {
  color: rgba(255, 255, 255, 0.7);
}

.gedit-document-panel {
  background-color: white;
}

.gedit-document-panel row button.flat {
  margin-top: 8px;
  margin-bottom: 8px;
}

.gedit-document-panel-group-row:not(:first-child) {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.gedit-side-panel-paned statusbar {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.gedit-search-slider {
  margin: 4px 4px 8px;
}

.gedit-search-slider entry:dir(ltr), .gedit-search-slider entry:dir(rtl) {
  border-radius: 2px;
}

.gedit-search-slider entry:dir(ltr) .gedit-search-entry-occurrences-tag, .gedit-search-slider entry:dir(rtl) .gedit-search-entry-occurrences-tag {
  all: unset;
  color: rgba(21, 22, 28, 0.38);
}

.gedit-search-slider entry:dir(ltr) {
  margin-right: -66px;
  padding-right: 66px;
}

.gedit-search-slider entry:dir(ltr) .gedit-search-entry-occurrences-tag {
  margin-left: 6px;
}

.gedit-search-slider entry:dir(ltr) image.right {
  margin-right: 0;
}

.gedit-search-slider entry:dir(rtl) {
  margin-left: -66px;
  padding-left: 66px;
}

.gedit-search-slider entry:dir(rtl) .gedit-search-entry-occurrences-tag {
  margin-right: 6px;
}

.gedit-search-slider entry:dir(rtl) image.left {
  margin-left: 0;
}

.gedit-search-slider entry.error ~ button {
  color: rgba(255, 255, 255, 0.7);
}

.gedit-search-slider entry.error ~ button:hover, .gedit-search-slider entry.error ~ button:active {
  color: #FFFFFF;
}

.gedit-search-slider entry.error ~ button:disabled {
  color: rgba(255, 255, 255, 0.3);
}

.gedit-search-slider button {
  border: solid 6px transparent;
}

.gedit-search-slider button:last-child:dir(ltr), .gedit-search-slider button:not(:first-child):dir(rtl) {
  margin-left: -3px;
}

.gedit-search-slider button:first-child:dir(rtl), .gedit-search-slider button:not(:last-child):dir(ltr) {
  margin-right: -3px;
}

frame.gedit-map-frame > border:dir(ltr) {
  border-style: none none none solid;
}

frame.gedit-map-frame > border:dir(rtl) {
  border-style: none solid none none;
}

/**************
 * Tweak Tool *
 **************/
.tweak-categories {
  background-image: image(white);
}

.tweak-categories .tweak-category:selected {
  background-color: #4D90D6;
}

.tweak-categories .tweak-category:selected:backdrop {
  background-color: #a8c4e0;
}

.tweak {
  padding: 3px;
}

.tweak.title:hover {
  box-shadow: none;
}

.tweak-group-white,
.tweak-white,
.tweak-white:hover {
  background-image: image(#FFFFFF);
}

.tweak-startup,
.tweak-startup:hover {
  background-image: image(#FFFFFF);
}

.tweak-group-startup {
  background-image: image(#FFFFFF);
  border: 1px solid rgba(0, 0, 0, 0.12);
}

row#Focus,
row#StaticWorkspaceTweak,
row#PrimaryWorkspaceTweak {
  padding: 0;
  border: 1px solid rgba(0, 0, 0, 0.12);
}

row#Focus row:not(:last-child),
row#StaticWorkspaceTweak row:not(:last-child),
row#PrimaryWorkspaceTweak row:not(:last-child) {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

row#Focus,
row#PrimaryWorkspaceTweak {
  margin-top: 4px;
}

/***********
 * Builder *
 ***********/
window.workbench > stack.titlebar headerbar omnibar.linked.horizontal entry:first-child {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  padding-right: 3px;
  border-right: 0 transparent;
}

window.workbench > stack.titlebar headerbar omnibar.linked.horizontal button:last-child {
  transition: all 270ms cubic-bezier(0.4, 0, 0.2, 1), box-shadow 180ms cubic-bezier(0.4, 0, 0.2, 1);
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), rgba(0, 0, 0, 0.26) 100%, transparent 0%) 0 0 2/0 0 2px;
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04), 0 1px 2px rgba(0, 0, 0, 0.08);
  background-color: #FFFFFF;
  color: rgba(21, 22, 28, 0.85);
  background-color: white;
  padding-left: 1em;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  border-left: 0 transparent;
}

window.workbench > stack.titlebar headerbar omnibar.linked.horizontal button:last-child:backdrop {
  color: rgba(125, 125, 125, 0.895);
}

window.workbench > stack.titlebar headerbar omnibar.linked.horizontal button:last-child:hover {
  background-color: #FFFFFF;
}

button.dzlmenubutton image {
  min-width: 26px;
}

button.dzlmenubutton image.arrow {
  min-width: 23px;
}

button.dzlmenubuttonitem {
  color: rgba(21, 22, 28, 0.85);
  font-weight: normal;
}

button.dzlmenubuttonitem:disabled {
  color: rgba(21, 22, 28, 0.38);
}

idelayoutstackheader {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

idelayoutstackheader button:checked {
  color: rgba(21, 22, 28, 0.85);
}

ideeditorutilities > dzldockpaned > box > stackswitcher {
  background-color: white;
}

ideeditorutilities > dzldockpaned > box > stackswitcher:dir(ltr) {
  border-right: 1px solid rgba(0, 0, 0, 0.12);
}

ideeditorutilities > dzldockpaned > box > stackswitcher:dir(rtl) {
  border-left: 1px solid rgba(0, 0, 0, 0.12);
}

ideeditorutilities > dzldockpaned > box > stackswitcher button {
  background-color: transparent;
}

ideeditorutilities > dzldockpaned > box > stackswitcher button:active {
  background-color: #4D90D6;
}

ideeditorsidebar notebook header {
  background: transparent;
}

popover.messagepopover list {
  border: 1px solid rgba(0, 0, 0, 0.12);
}

popover.messagepopover list row:not(:last-child) {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

/**********
 * Photos *
 **********/
GdMainIconView.content-view {
  -GdMainIconView-icon-size: 48;
}

.documents-counter {
  margin: 8px;
  border-radius: 9999px;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23);
  background-color: #4D90D6;
  color: #FFFFFF;
  font-weight: bold;
}

.documents-scrolledwin.frame {
  border-style: none;
}

.documents-scrolledwin.frame frame.content-view > border {
  border-style: none;
}

.photos-fade-in {
  opacity: 1;
  transition: opacity 180ms cubic-bezier(0, 0, 0.2, 1);
}

.photos-fade-out {
  opacity: 0;
  transition: opacity 180ms cubic-bezier(0, 0, 0.2, 1);
}

overlay grid.horizontal > revealer > scrolledwindow.frame:dir(ltr) {
  border-style: none none none solid;
}

overlay grid.horizontal > revealer > scrolledwindow.frame:dir(rtl) {
  border-style: none solid none none;
}

/*********
 * Music *
 *********/
.side-panel:dir(ltr) {
  border-style: solid;
  border-color: rgba(0, 0, 0, 0.12);
}

.side-panel:dir(rtl) {
  border-style: solid;
  border-color: rgba(0, 0, 0, 0.12);
}

.side-panel .view {
  background-image: image(white);
}

.side-panel .view:hover {
  background-image: image(rgba(246, 246, 246, 0.9925));
}

.side-panel .view:selected {
  background-image: image(#4D90D6);
}

.side-panel .view:selected:hover {
  background-image: image(#5696d8);
}

.songs-list:hover {
  background-image: image(alpha(currentColor, 0.05));
}

frame.documents-dropdown {
  margin: 8px;
}

frame.documents-dropdown > border {
  border: none;
}

box.vertical > revealer > toolbar.search-bar {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  background-clip: border-box;
}

box.vertical > revealer > toolbar.search-bar button > widget {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

/*********
 * To Do *
 *********/
taskrow {
  transition: all 180ms cubic-bezier(0.4, 0, 0.2, 1);
  margin: 0 -8px;
}

taskrow:hover {
  transition: none;
}

taskrow label {
  margin: 0 8px;
}

taskrow image {
  min-width: 16px;
}

task-list-view > box > revealer > box > button {
  margin: -4px;
}

/*******
 * eog *
 *******/
#eog-thumb-nav scrolledwindow {
  border-top: none;
}

#eog-thumb-nav button {
  -gtk-outline-radius: 2px;
}

/*************
 * Evolution *
 *************/
frame.taskbar > border {
  border-style: solid none none;
}

box.vertical > paned.horizontal notebook widget .frame {
  border-style: none;
}

/********
 * gitg *
 ********/
frame.commit-frame > border {
  border-style: solid none none;
}

/**************
 * Characters *
 **************/
box.dialog-vbox scrolledwindow.related {
  border: 1px solid rgba(0, 0, 0, 0.12);
}

list.categories {
  background-image: image(white);
}

/*********
 * Boxes *
 *********/
.transparent-bg + stack overlay > label {
  min-height: 24px;
  padding: 0 4px;
  border-radius: 4px;
  background-color: rgba(0, 0, 0, 0.3);
  color: #FFFFFF;
}

/**************
 * Calculator *
 **************/
button.title label {
  min-height: 32px;
}

/*********
 * Geary *
 *********/
.geary-titlebar-left:dir(ltr) {
  margin-right: 5px;
  padding-right: 0;
}

.geary-titlebar-left:dir(rtl) {
  margin-left: 5px;
  padding-left: 0;
}

.geary-titlebar-left > separator {
  background-color: rgba(0, 0, 0, 0.05);
}

.geary-titlebar-right:dir(ltr) {
  margin-left: -5px;
}

.geary-titlebar-right:dir(rtl) {
  margin-right: -5px;
}

dialog.background > box.dialog-vbox > box.dialog-action-box > buttonbox.dialog-action-area {
  padding: 12px;
}

.geary-expanded > .geary-composer-embed > widget headerbar image,
.geary-expanded > .geary-composer-embed > widget headerbar label {
  color: rgba(255, 255, 255, 0.85);
}

/************************
 * LightDM GTK+ Greeter *
 ************************/
#panel_window {
  background-color: rgba(0, 0, 0, 0.3);
  color: #FFFFFF;
}

#panel_window menubar,
#panel_window separator {
  background-color: transparent;
}

#panel_window separator {
  padding: 0 4px;
}

#panel_window separator:first-child {
  padding: 0 8px;
}

#panel_window menubar > menuitem {
  color: rgba(255, 255, 255, 0.7);
}

#panel_window menubar > menuitem:hover {
  color: #FFFFFF;
}

#panel_window menubar > menuitem:disabled label {
  color: rgba(255, 255, 255, 0.3);
}

#login_window,
#shutdown_dialog,
#restart_dialog {
  margin: 8px;
  border-radius: 2px;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23), inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: white;
}

#content_frame {
  padding-bottom: 20px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

#buttonbox_frame {
  padding-top: 24px;
}

#buttonbox_frame button {
  margin: -16px;
}

#greeter_infobar {
  margin-top: -1px;
}

/*
 * Most of this is adapted directly from the elementaryOS stylesheet.
 * https://github.com/elementary/stylesheet/blob/master/gtk-3.0/granite-widgets.css
 * Original code copyright (c) 2016 elementary LLC. (http://launchpad.net/egtk)
 *
 * Modifications copyright (c) 2017 System76, Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authored by:
 *              Daniel Fore <daniel@elementary.io>
 *              Ian Santopietro <ian@system76.com>
 */
/****************
 * Back Buttons *
 ****************/
button.back-button,
.titlebar .back-button {
  background-image: -gtk-icontheme("go-previous-symbolic");
  background-size: 16px;
  background-position: 12px 50%;
  background-color: transparent;
  background-repeat: no-repeat no-repeat;
  padding-left: 36px;
  box-shadow: none;
}

/***************
 * Text Styles *
 ***************/
.h1 {
  font-size: 24px;
}

.h2 {
  font-weight: 300;
  font-size: 18px;
}

.h3 {
  font-size: 11px;
}

.h4,
.category-label {
  font-weight: bold;
}

.h4 {
  padding-bottom: 6px;
  padding-top: 6px;
}

list .h4,
listbox .h4 {
  padding-left: 6px;
}

/***********
 * Welcome *
 ***********/
.welcome {
  font-size: 10px;
  text-shadow: none;
}

.welcome .dim-label, .welcome label.separator, .welcome .titlebar:not(headerbar) .subtitle, .titlebar:not(headerbar) .welcome .subtitle, .welcome
headerbar .subtitle,
headerbar .welcome .subtitle, .welcome .budgie-notification .notification-body, .budgie-notification .welcome .notification-body, .welcome .budgie-switcher .notification-body, .budgie-switcher .welcome .notification-body {
  color: rgba(21, 22, 28, 0.54);
}

.welcome .h1,
.welcome .h3 {
  color: rgba(21, 22, 28, 0.8);
}

/***************
 * Storage Bar *
 ***************/
.storage-bar .trough {
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.16), 0 3px 3px rgba(0, 0, 0, 0.23);
  border: none;
  background-image: none;
  padding: 8px 6px;
}

.storage-bar .fill-block {
  background-color: #d9d9d9;
  border: 1px solid rgba(0, 0, 0, 0.35);
  border-left-width: 0;
  border-right-width: 0;
  border-top-width: 0;
  border-bottom-width: 1px;
  border-bottom-color: #a6a6a6;
  padding: 8px 6px;
}

.storage-bar .empty-block {
  background-color: #f2f2f2;
  border-bottom-width: 1px;
  border-bottom-color: #999999;
}

.storage-bar .app {
  background-color: #9C27B0;
  border-bottom-width: 1px;
  border-bottom-color: #52145d;
}

.storage-bar .audio {
  background-color: #f04a50;
  border-bottom-width: 1px;
  border-bottom-color: #c41017;
}

.storage-bar .files {
  background-color: #4D90D6;
  border-bottom-width: 1px;
  border-bottom-color: #235d9a;
}

.storage-bar .photo {
  background-color: #73d216;
  border-bottom-width: 1px;
  border-bottom-color: #40760c;
}

.storage-bar .video {
  background-color: #fc4138;
  border-bottom-width: 1px;
  border-bottom-color: #660602;
}

.storage-bar .legend {
  padding: 8px;
  border-radius: 50%;
}

/**************
 * Round Apps *
 **************/
window.rounded,
window.rounded .action-bar {
  border-radius: 0 0 4px 4px;
}

window.rounded.window-frame {
  border-radius: 4px;
}

window.rounded decoration {
  border-radius: 4px;
}

/******************
 * Pantheon Panel *
 ******************/
.panel {
  background-color: black;
  transition: all 100ms ease-in-out;
  font-weight: normal;
}

/**********
 * Harvey *
 **********/
window.background.csd.rounded > grid.titlebar {
  min-height: 0;
}

window.background.csd.rounded > grid.titlebar > headerbar.input-header {
  border-top-right-radius: 0;
  background-color: white;
}

window.background.csd.rounded > grid.titlebar > headerbar.input-header > box.left > button.close {
  color: rgba(21, 22, 28, 0.85);
}

window.background.csd.rounded > grid.titlebar > headerbar.input-header > box.left > button.close:backdrop {
  background-color: rgba(56, 60, 74, 0.12);
}

/************
 * Spice-Up *
 ************/
window.csd > overlay > stack > grid.app-back > revealer > box.toolbar box.frame button.image-button,
window.csd > overlay > stack > grid.app-back > revealer > box.toolbar box.frame button.entry,
window.csd > overlay > stack > grid.app-back > revealer > box.toolbar box.frame entry {
  background-color: transparent;
  box-shadow: none;
}

window.csd headerbar.titlebar button.suggested-action {
  background-color: #437a0d;
}

/*************
 * AppCenter *
 *************/
row.activatable > grid.horizontal > stack, .view > grid.horizontal > stack, treeview.view header button > grid.horizontal > stack, .budgie-menu button > grid.horizontal > stack {
  padding: 8px;
}

/**********
 * Photos *
 **********/
.checkerboard-layout {
  background-color: #5c616c;
  background-image: linear-gradient(45deg, rgba(0, 0, 0, 0.1) 25%, transparent 25%, transparent 75%, rgba(0, 0, 0, 0.1) 75%, rgba(0, 0, 0, 0.1)), linear-gradient(45deg, rgba(0, 0, 0, 0.1) 25%, transparent 25%, transparent 75%, rgba(0, 0, 0, 0.1) 75%, rgba(0, 0, 0, 0.1));
  background-size: 24px 24px;
  background-position: 0 0, 12px 12px;
}

.checkboard-layout .item {
  background-color: white;
}

/************
 * Terminal *
 ************/
.search-bar {
  background-color: white;
}

.search-bar entry {
  background-color: rgba(255, 255, 255, 0.1);
}

.color-button {
  border: 1px solid rgba(0, 0, 0, 0.12);
  -gtk-outline-radius: 50%;
}

/*************
 * Titlebars *
 *************/
.csd .default-decoration {
  padding-top: 0;
  padding-bottom: 0;
  min-height: 24px;
}

.csd .default-decoration button {
  margin-top: 0;
  margin-bottom: 0;
}

.csd .default-decoration .title {
  padding-top: 6px;
  padding-bottom: 6px;
}

.lightdm menu {
  background-image: none;
  background-color: shade(white, 1.08);
  border: none;
  border-radius: 0px;
  padding: 1px;
  color: rgba(56, 60, 74, 0.85);
}

.lightdm-combo menu {
  background-color: shade(white, 1.08);
  border-radius: 0px;
  padding: 0px;
  color: rgba(56, 60, 74, 0.85);
}

.lightdm menu menuitem *,
.lightdm menu menuitem.check:active,
.lightdm menu menuitem.radio:active {
  color: rgba(56, 60, 74, 0.85);
}

.lightdm menu menuitem *:disabled {
  color: inherit;
  text-shadow: inherit;
}

.lightdm menu separator {
  border: inherit;
  background-color: alpha(#000000, 0.05);
  border-color: alpha(#000000, 0.07);
}

.lightdm menubar {
  background-image: none;
  background-color: alpha(#000000, 0.5);
}

.lightdm-combo cell,
.lightdm-combo button,
.lightdm-combo entry,
.lightdm button,
.lightdm entry {
  background-image: none;
  background-color: alpha(#000000, 0.3);
  border-color: alpha(#FFFFFF, 0.6);
  border-radius: 5px;
  padding: 7px;
  color: #FFFFFF;
  text-shadow: none;
}

.lightdm button,
.lightdm button:hover,
.lightdm button:active,
.lightdm button:active:focus,
.lightdm entry,
.lightdm entry:hover,
.lightdm entry:active,
.lightdm entry:active:focus {
  background-image: none;
  border-image: none;
}

.lightdm button:focus,
.lightdm entry:focus {
  border-color: alpha(#FFFFFF, 0.9);
  border-width: 0px;
  border-style: none;
  background-color: rgba(0, 0, 0, 0.15);
  color: #FFFFFF;
}

.lightdm entry:selected {
  background-color: alpha(#FFFFFF, 0.2);
  border-bottom: 0px transparent;
}

@keyframes dashentry_spinner {
  to {
    -gtk-icon-transform: rotate(1turn);
  }
}

.lightdm entry:active {
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
  animation: dashentry_spinner 1s infinite linear;
}

.lightdm .option-button {
  padding: 2px;
  background: none;
  border: 0;
}

.lightdm .toggle-button {
  background: none;
  border-width: 0;
}

.lightdm .toggle-button.selected {
  background-color: alpha(#000000, 0.3);
  border-width: 1px;
}

/* GTK NAMED COLORS
   ----------------
   use responsibly! */
/*
widget text/foreground color */
@define-color theme_fg_color rgba(21, 22, 28, 0.85);
/*
text color for entries, views and content in general */
@define-color theme_text_color rgba(21, 22, 28, 0.85);
/*
widget base background color */
@define-color theme_bg_color white;
@define-color bg_color white;
/*
text widgets and the like base background color */
@define-color theme_base_color #FFFFFF;
/*
base background color of selections */
@define-color theme_selected_bg_color #4D90D6;
/*
text/foreground color of selections */
@define-color theme_selected_fg_color #FFFFFF;
/*
base background color of insensitive widgets */
@define-color insensitive_bg_color white;
/*
text foreground color of insensitive widgets */
@define-color insensitive_fg_color rgba(21, 22, 28, 0.38);
/*
insensitive text widgets and the like base background color */
@define-color insensitive_base_color white;
/*
widget text/foreground color on backdrop windows */
@define-color theme_unfocused_fg_color rgba(21, 22, 28, 0.85);
/*
text color for entries, views and content in general on backdrop windows */
@define-color theme_unfocused_text_color rgba(21, 22, 28, 0.85);
/*
widget base background color on backdrop windows */
@define-color theme_unfocused_bg_color white;
/*
text widgets and the like base background color on backdrop windows */
@define-color theme_unfocused_base_color #FFFFFF;
/*
base background color of selections on backdrop windows */
@define-color theme_unfocused_selected_bg_color #4D90D6;
/*
text/foreground color of selections on backdrop windows */
@define-color theme_unfocused_selected_fg_color #FFFFFF;
/*
insensitive color on backdrop windows */
@define-color unfocused_insensitive_color rgba(21, 22, 28, 0.38);
/*
widgets main borders color */
@define-color borders rgba(0, 0, 0, 0.12);
/*
widgets main borders color on backdrop windows */
@define-color unfocused_borders rgba(0, 0, 0, 0.12);
/*
these are pretty self explicative */
@define-color warning_color #e0a100;
@define-color error_color #c10c03;
@define-color success_color #132304;
@define-color destructive_color #f80f04;
@define-color suggested_color #437a0d;
/*
this is really an API */
@define-color content_view_bg #FFFFFF;
@define-color placeholder_text_color #757575;
/*
These are for Spice-up Presentation maker*/
@define-color SpicePrimaryBackground #15161c;
@define-color SpiceSlideBackground #20222a;
@define-color SpiceSlideBackgroundSelected #242730;
@define-color colorPrimary #4D90D6;
